@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/directconnect/DirectConnect_EXPORTS.h>
@@ -20,6 +10,7 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/directconnect/model/HasLogicalRedundancy.h>
 #include <aws/directconnect/model/Connection.h>
+#include <aws/directconnect/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -554,6 +545,78 @@ namespace Model
      */
     inline DeleteLagResult& WithHasLogicalRedundancy(HasLogicalRedundancy&& value) { SetHasLogicalRedundancy(std::move(value)); return *this;}
 
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tags = value; }
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tags = std::move(value); }
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline DeleteLagResult& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline DeleteLagResult& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline DeleteLagResult& AddTags(const Tag& value) { m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>The tags associated with the LAG.</p>
+     */
+    inline DeleteLagResult& AddTags(Tag&& value) { m_tags.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline const Aws::String& GetProviderName() const{ return m_providerName; }
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline void SetProviderName(const Aws::String& value) { m_providerName = value; }
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline void SetProviderName(Aws::String&& value) { m_providerName = std::move(value); }
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline void SetProviderName(const char* value) { m_providerName.assign(value); }
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline DeleteLagResult& WithProviderName(const Aws::String& value) { SetProviderName(value); return *this;}
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline DeleteLagResult& WithProviderName(Aws::String&& value) { SetProviderName(std::move(value)); return *this;}
+
+    /**
+     * <p>The name of the service provider associated with the LAG.</p>
+     */
+    inline DeleteLagResult& WithProviderName(const char* value) { SetProviderName(value); return *this;}
+
   private:
 
     Aws::String m_connectionsBandwidth;
@@ -585,6 +648,10 @@ namespace Model
     bool m_jumboFrameCapable;
 
     HasLogicalRedundancy m_hasLogicalRedundancy;
+
+    Aws::Vector<Tag> m_tags;
+
+    Aws::String m_providerName;
   };
 
 } // namespace Model
