@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/lex-models/LexModelBuildingService_EXPORTS.h>
@@ -23,6 +13,7 @@
 #include <aws/core/utils/DateTime.h>
 #include <aws/lex-models/model/Locale.h>
 #include <aws/lex-models/model/Intent.h>
+#include <aws/lex-models/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -164,6 +155,68 @@ namespace Model
     inline PutBotResult& AddIntents(Intent&& value) { m_intents.push_back(std::move(value)); return *this; }
 
 
+    /**
+     * <p>Indicates whether the bot uses accuracy improvements. <code>true</code>
+     * indicates that the bot is using the improvements, otherwise,
+     * <code>false</code>.</p>
+     */
+    inline bool GetEnableModelImprovements() const{ return m_enableModelImprovements; }
+
+    /**
+     * <p>Indicates whether the bot uses accuracy improvements. <code>true</code>
+     * indicates that the bot is using the improvements, otherwise,
+     * <code>false</code>.</p>
+     */
+    inline void SetEnableModelImprovements(bool value) { m_enableModelImprovements = value; }
+
+    /**
+     * <p>Indicates whether the bot uses accuracy improvements. <code>true</code>
+     * indicates that the bot is using the improvements, otherwise,
+     * <code>false</code>.</p>
+     */
+    inline PutBotResult& WithEnableModelImprovements(bool value) { SetEnableModelImprovements(value); return *this;}
+
+
+    /**
+     * <p>The score that determines where Amazon Lex inserts the
+     * <code>AMAZON.FallbackIntent</code>, <code>AMAZON.KendraSearchIntent</code>, or
+     * both when returning alternative intents in a <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostContent.html">PostContent</a>
+     * or <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostText.html">PostText</a>
+     * response. <code>AMAZON.FallbackIntent</code> is inserted if the confidence score
+     * for all intents is below this value. <code>AMAZON.KendraSearchIntent</code> is
+     * only inserted if it is configured for the bot.</p>
+     */
+    inline double GetNluIntentConfidenceThreshold() const{ return m_nluIntentConfidenceThreshold; }
+
+    /**
+     * <p>The score that determines where Amazon Lex inserts the
+     * <code>AMAZON.FallbackIntent</code>, <code>AMAZON.KendraSearchIntent</code>, or
+     * both when returning alternative intents in a <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostContent.html">PostContent</a>
+     * or <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostText.html">PostText</a>
+     * response. <code>AMAZON.FallbackIntent</code> is inserted if the confidence score
+     * for all intents is below this value. <code>AMAZON.KendraSearchIntent</code> is
+     * only inserted if it is configured for the bot.</p>
+     */
+    inline void SetNluIntentConfidenceThreshold(double value) { m_nluIntentConfidenceThreshold = value; }
+
+    /**
+     * <p>The score that determines where Amazon Lex inserts the
+     * <code>AMAZON.FallbackIntent</code>, <code>AMAZON.KendraSearchIntent</code>, or
+     * both when returning alternative intents in a <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostContent.html">PostContent</a>
+     * or <a
+     * href="https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostText.html">PostText</a>
+     * response. <code>AMAZON.FallbackIntent</code> is inserted if the confidence score
+     * for all intents is below this value. <code>AMAZON.KendraSearchIntent</code> is
+     * only inserted if it is configured for the bot.</p>
+     */
+    inline PutBotResult& WithNluIntentConfidenceThreshold(double value) { SetNluIntentConfidenceThreshold(value); return *this;}
+
+
     /**
      * <p> The prompts that Amazon Lex uses when it doesn't understand the user's
      * intent. For more information, see <a>PutBot</a>. </p>
@@ -196,31 +249,31 @@ namespace Model
 
 
     /**
-     * <p>The message that Amazon Lex uses to abort a conversation. For more
+     * <p>The message that Amazon Lex uses to cancel a conversation. For more
      * information, see <a>PutBot</a>.</p>
      */
     inline const Statement& GetAbortStatement() const{ return m_abortStatement; }
 
     /**
-     * <p>The message that Amazon Lex uses to abort a conversation. For more
+     * <p>The message that Amazon Lex uses to cancel a conversation. For more
      * information, see <a>PutBot</a>.</p>
      */
     inline void SetAbortStatement(const Statement& value) { m_abortStatement = value; }
 
     /**
-     * <p>The message that Amazon Lex uses to abort a conversation. For more
+     * <p>The message that Amazon Lex uses to cancel a conversation. For more
      * information, see <a>PutBot</a>.</p>
      */
     inline void SetAbortStatement(Statement&& value) { m_abortStatement = std::move(value); }
 
     /**
-     * <p>The message that Amazon Lex uses to abort a conversation. For more
+     * <p>The message that Amazon Lex uses to cancel a conversation. For more
      * information, see <a>PutBot</a>.</p>
      */
     inline PutBotResult& WithAbortStatement(const Statement& value) { SetAbortStatement(value); return *this;}
 
     /**
-     * <p>The message that Amazon Lex uses to abort a conversation. For more
+     * <p>The message that Amazon Lex uses to cancel a conversation. For more
      * information, see <a>PutBot</a>.</p>
      */
     inline PutBotResult& WithAbortStatement(Statement&& value) { SetAbortStatement(std::move(value)); return *this;}
@@ -229,60 +282,75 @@ namespace Model
     /**
      * <p> When you send a request to create a bot with <code>processBehavior</code>
      * set to <code>BUILD</code>, Amazon Lex sets the <code>status</code> response
-     * element to <code>BUILDING</code>. After Amazon Lex builds the bot, it sets
-     * <code>status</code> to <code>READY</code>. If Amazon Lex can't build the bot,
-     * Amazon Lex sets <code>status</code> to <code>FAILED</code>. Amazon Lex returns
-     * the reason for the failure in the <code>failureReason</code> response element.
-     * </p> <p>When you set <code>processBehavior</code>to <code>SAVE</code>, Amazon
-     * Lex sets the status code to <code>NOT BUILT</code>.</p>
+     * element to <code>BUILDING</code>.</p> <p>In the <code>READY_BASIC_TESTING</code>
+     * state you can test the bot with user inputs that exactly match the utterances
+     * configured for the bot's intents and values in the slot types.</p> <p>If Amazon
+     * Lex can't build the bot, Amazon Lex sets <code>status</code> to
+     * <code>FAILED</code>. Amazon Lex returns the reason for the failure in the
+     * <code>failureReason</code> response element. </p> <p>When you set
+     * <code>processBehavior</code> to <code>SAVE</code>, Amazon Lex sets the status
+     * code to <code>NOT BUILT</code>.</p> <p>When the bot is in the <code>READY</code>
+     * state you can test and publish the bot.</p>
      */
     inline const Status& GetStatus() const{ return m_status; }
 
     /**
      * <p> When you send a request to create a bot with <code>processBehavior</code>
      * set to <code>BUILD</code>, Amazon Lex sets the <code>status</code> response
-     * element to <code>BUILDING</code>. After Amazon Lex builds the bot, it sets
-     * <code>status</code> to <code>READY</code>. If Amazon Lex can't build the bot,
-     * Amazon Lex sets <code>status</code> to <code>FAILED</code>. Amazon Lex returns
-     * the reason for the failure in the <code>failureReason</code> response element.
-     * </p> <p>When you set <code>processBehavior</code>to <code>SAVE</code>, Amazon
-     * Lex sets the status code to <code>NOT BUILT</code>.</p>
+     * element to <code>BUILDING</code>.</p> <p>In the <code>READY_BASIC_TESTING</code>
+     * state you can test the bot with user inputs that exactly match the utterances
+     * configured for the bot's intents and values in the slot types.</p> <p>If Amazon
+     * Lex can't build the bot, Amazon Lex sets <code>status</code> to
+     * <code>FAILED</code>. Amazon Lex returns the reason for the failure in the
+     * <code>failureReason</code> response element. </p> <p>When you set
+     * <code>processBehavior</code> to <code>SAVE</code>, Amazon Lex sets the status
+     * code to <code>NOT BUILT</code>.</p> <p>When the bot is in the <code>READY</code>
+     * state you can test and publish the bot.</p>
      */
     inline void SetStatus(const Status& value) { m_status = value; }
 
     /**
      * <p> When you send a request to create a bot with <code>processBehavior</code>
      * set to <code>BUILD</code>, Amazon Lex sets the <code>status</code> response
-     * element to <code>BUILDING</code>. After Amazon Lex builds the bot, it sets
-     * <code>status</code> to <code>READY</code>. If Amazon Lex can't build the bot,
-     * Amazon Lex sets <code>status</code> to <code>FAILED</code>. Amazon Lex returns
-     * the reason for the failure in the <code>failureReason</code> response element.
-     * </p> <p>When you set <code>processBehavior</code>to <code>SAVE</code>, Amazon
-     * Lex sets the status code to <code>NOT BUILT</code>.</p>
+     * element to <code>BUILDING</code>.</p> <p>In the <code>READY_BASIC_TESTING</code>
+     * state you can test the bot with user inputs that exactly match the utterances
+     * configured for the bot's intents and values in the slot types.</p> <p>If Amazon
+     * Lex can't build the bot, Amazon Lex sets <code>status</code> to
+     * <code>FAILED</code>. Amazon Lex returns the reason for the failure in the
+     * <code>failureReason</code> response element. </p> <p>When you set
+     * <code>processBehavior</code> to <code>SAVE</code>, Amazon Lex sets the status
+     * code to <code>NOT BUILT</code>.</p> <p>When the bot is in the <code>READY</code>
+     * state you can test and publish the bot.</p>
      */
     inline void SetStatus(Status&& value) { m_status = std::move(value); }
 
     /**
      * <p> When you send a request to create a bot with <code>processBehavior</code>
      * set to <code>BUILD</code>, Amazon Lex sets the <code>status</code> response
-     * element to <code>BUILDING</code>. After Amazon Lex builds the bot, it sets
-     * <code>status</code> to <code>READY</code>. If Amazon Lex can't build the bot,
-     * Amazon Lex sets <code>status</code> to <code>FAILED</code>. Amazon Lex returns
-     * the reason for the failure in the <code>failureReason</code> response element.
-     * </p> <p>When you set <code>processBehavior</code>to <code>SAVE</code>, Amazon
-     * Lex sets the status code to <code>NOT BUILT</code>.</p>
+     * element to <code>BUILDING</code>.</p> <p>In the <code>READY_BASIC_TESTING</code>
+     * state you can test the bot with user inputs that exactly match the utterances
+     * configured for the bot's intents and values in the slot types.</p> <p>If Amazon
+     * Lex can't build the bot, Amazon Lex sets <code>status</code> to
+     * <code>FAILED</code>. Amazon Lex returns the reason for the failure in the
+     * <code>failureReason</code> response element. </p> <p>When you set
+     * <code>processBehavior</code> to <code>SAVE</code>, Amazon Lex sets the status
+     * code to <code>NOT BUILT</code>.</p> <p>When the bot is in the <code>READY</code>
+     * state you can test and publish the bot.</p>
      */
     inline PutBotResult& WithStatus(const Status& value) { SetStatus(value); return *this;}
 
     /**
      * <p> When you send a request to create a bot with <code>processBehavior</code>
      * set to <code>BUILD</code>, Amazon Lex sets the <code>status</code> response
-     * element to <code>BUILDING</code>. After Amazon Lex builds the bot, it sets
-     * <code>status</code> to <code>READY</code>. If Amazon Lex can't build the bot,
-     * Amazon Lex sets <code>status</code> to <code>FAILED</code>. Amazon Lex returns
-     * the reason for the failure in the <code>failureReason</code> response element.
-     * </p> <p>When you set <code>processBehavior</code>to <code>SAVE</code>, Amazon
-     * Lex sets the status code to <code>NOT BUILT</code>.</p>
+     * element to <code>BUILDING</code>.</p> <p>In the <code>READY_BASIC_TESTING</code>
+     * state you can test the bot with user inputs that exactly match the utterances
+     * configured for the bot's intents and values in the slot types.</p> <p>If Amazon
+     * Lex can't build the bot, Amazon Lex sets <code>status</code> to
+     * <code>FAILED</code>. Amazon Lex returns the reason for the failure in the
+     * <code>failureReason</code> response element. </p> <p>When you set
+     * <code>processBehavior</code> to <code>SAVE</code>, Amazon Lex sets the status
+     * code to <code>NOT BUILT</code>.</p> <p>When the bot is in the <code>READY</code>
+     * state you can test and publish the bot.</p>
      */
     inline PutBotResult& WithStatus(Status&& value) { SetStatus(std::move(value)); return *this;}
 
@@ -636,15 +704,88 @@ namespace Model
     inline PutBotResult& WithChildDirected(bool value) { SetChildDirected(value); return *this;}
 
 
-    
+    /**
+     * <p> <code>True</code> if a new version of the bot was created. If the
+     * <code>createVersion</code> field was not specified in the request, the
+     * <code>createVersion</code> field is set to false in the response.</p>
+     */
     inline bool GetCreateVersion() const{ return m_createVersion; }
 
-    
+    /**
+     * <p> <code>True</code> if a new version of the bot was created. If the
+     * <code>createVersion</code> field was not specified in the request, the
+     * <code>createVersion</code> field is set to false in the response.</p>
+     */
     inline void SetCreateVersion(bool value) { m_createVersion = value; }
 
-    
+    /**
+     * <p> <code>True</code> if a new version of the bot was created. If the
+     * <code>createVersion</code> field was not specified in the request, the
+     * <code>createVersion</code> field is set to false in the response.</p>
+     */
     inline PutBotResult& WithCreateVersion(bool value) { SetCreateVersion(value); return *this;}
 
+
+    /**
+     * <p> <code>true</code> if the bot is configured to send user utterances to Amazon
+     * Comprehend for sentiment analysis. If the <code>detectSentiment</code> field was
+     * not specified in the request, the <code>detectSentiment</code> field is
+     * <code>false</code> in the response.</p>
+     */
+    inline bool GetDetectSentiment() const{ return m_detectSentiment; }
+
+    /**
+     * <p> <code>true</code> if the bot is configured to send user utterances to Amazon
+     * Comprehend for sentiment analysis. If the <code>detectSentiment</code> field was
+     * not specified in the request, the <code>detectSentiment</code> field is
+     * <code>false</code> in the response.</p>
+     */
+    inline void SetDetectSentiment(bool value) { m_detectSentiment = value; }
+
+    /**
+     * <p> <code>true</code> if the bot is configured to send user utterances to Amazon
+     * Comprehend for sentiment analysis. If the <code>detectSentiment</code> field was
+     * not specified in the request, the <code>detectSentiment</code> field is
+     * <code>false</code> in the response.</p>
+     */
+    inline PutBotResult& WithDetectSentiment(bool value) { SetDetectSentiment(value); return *this;}
+
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tags = value; }
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tags = std::move(value); }
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline PutBotResult& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline PutBotResult& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline PutBotResult& AddTags(const Tag& value) { m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>A list of tags associated with the bot.</p>
+     */
+    inline PutBotResult& AddTags(Tag&& value) { m_tags.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_name;
@@ -653,6 +794,10 @@ namespace Model
 
     Aws::Vector<Intent> m_intents;
 
+    bool m_enableModelImprovements;
+
+    double m_nluIntentConfidenceThreshold;
+
     Prompt m_clarificationPrompt;
 
     Statement m_abortStatement;
@@ -678,6 +823,10 @@ namespace Model
     bool m_childDirected;
 
     bool m_createVersion;
+
+    bool m_detectSentiment;
+
+    Aws::Vector<Tag> m_tags;
   };
 
 } // namespace Model
