@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/medialive/MediaLive_EXPORTS.h>
@@ -22,6 +12,7 @@
 #include <aws/medialive/model/InputType.h>
 #include <aws/medialive/model/InputVpcRequest.h>
 #include <aws/medialive/model/InputDestinationRequest.h>
+#include <aws/medialive/model/InputDeviceSettings.h>
 #include <aws/medialive/model/MediaConnectFlowRequest.h>
 #include <aws/medialive/model/InputSourceRequest.h>
 #include <utility>
@@ -43,7 +34,7 @@ namespace Model
   {
   public:
     CreateInputRequest();
-    
+
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -94,6 +85,47 @@ namespace Model
     inline CreateInputRequest& AddDestinations(InputDestinationRequest&& value) { m_destinationsHasBeenSet = true; m_destinations.push_back(std::move(value)); return *this; }
 
 
+    /**
+     * Settings for the devices.
+     */
+    inline const Aws::Vector<InputDeviceSettings>& GetInputDevices() const{ return m_inputDevices; }
+
+    /**
+     * Settings for the devices.
+     */
+    inline bool InputDevicesHasBeenSet() const { return m_inputDevicesHasBeenSet; }
+
+    /**
+     * Settings for the devices.
+     */
+    inline void SetInputDevices(const Aws::Vector<InputDeviceSettings>& value) { m_inputDevicesHasBeenSet = true; m_inputDevices = value; }
+
+    /**
+     * Settings for the devices.
+     */
+    inline void SetInputDevices(Aws::Vector<InputDeviceSettings>&& value) { m_inputDevicesHasBeenSet = true; m_inputDevices = std::move(value); }
+
+    /**
+     * Settings for the devices.
+     */
+    inline CreateInputRequest& WithInputDevices(const Aws::Vector<InputDeviceSettings>& value) { SetInputDevices(value); return *this;}
+
+    /**
+     * Settings for the devices.
+     */
+    inline CreateInputRequest& WithInputDevices(Aws::Vector<InputDeviceSettings>&& value) { SetInputDevices(std::move(value)); return *this;}
+
+    /**
+     * Settings for the devices.
+     */
+    inline CreateInputRequest& AddInputDevices(const InputDeviceSettings& value) { m_inputDevicesHasBeenSet = true; m_inputDevices.push_back(value); return *this; }
+
+    /**
+     * Settings for the devices.
+     */
+    inline CreateInputRequest& AddInputDevices(InputDeviceSettings&& value) { m_inputDevicesHasBeenSet = true; m_inputDevices.push_back(std::move(value)); return *this; }
+
+
     /**
      * A list of security groups referenced by IDs to attach to the input.
      */
@@ -573,6 +605,9 @@ Only specify sources for PULL type Inputs. Leave
     Aws::Vector<InputDestinationRequest> m_destinations;
     bool m_destinationsHasBeenSet;
 
+    Aws::Vector<InputDeviceSettings> m_inputDevices;
+    bool m_inputDevicesHasBeenSet;
+
     Aws::Vector<Aws::String> m_inputSecurityGroups;
     bool m_inputSecurityGroupsHasBeenSet;
 
