@@ -1,23 +1,15 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/organizations/Organizations_EXPORTS.h>
 #include <aws/organizations/OrganizationsRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/organizations/model/IAMUserAccessToBilling.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/organizations/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -33,7 +25,7 @@ namespace Model
   {
   public:
     CreateAccountRequest();
-    
+
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -167,16 +159,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline const Aws::String& GetRoleName() const{ return m_roleName; }
 
@@ -188,16 +181,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline bool RoleNameHasBeenSet() const { return m_roleNameHasBeenSet; }
 
@@ -209,16 +203,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline void SetRoleName(const Aws::String& value) { m_roleNameHasBeenSet = true; m_roleName = value; }
 
@@ -230,16 +225,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline void SetRoleName(Aws::String&& value) { m_roleNameHasBeenSet = true; m_roleName = std::move(value); }
 
@@ -251,16 +247,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline void SetRoleName(const char* value) { m_roleNameHasBeenSet = true; m_roleName.assign(value); }
 
@@ -272,16 +269,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline CreateAccountRequest& WithRoleName(const Aws::String& value) { SetRoleName(value); return *this;}
 
@@ -293,16 +291,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline CreateAccountRequest& WithRoleName(Aws::String&& value) { SetRoleName(std::move(value)); return *this;}
 
@@ -314,16 +313,17 @@ namespace Model
      * permissions in the new member account.</p> <p>If you don't specify this
      * parameter, the role name defaults to
      * <code>OrganizationAccountAccessRole</code>.</p> <p>For more information about
-     * how to use this role to access the member account, see <a
+     * how to use this role to access the member account, see the following links:</p>
+     * <ul> <li> <p> <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html#orgs_manage_accounts_create-cross-account-role">Accessing
      * and Administering the Member Accounts in Your Organization</a> in the <i>AWS
-     * Organizations User Guide</i>, and steps 2 and 3 in <a
+     * Organizations User Guide</i> </p> </li> <li> <p>Steps 2 and 3 in <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_cross-account-with-roles.html">Tutorial:
      * Delegate Access Across AWS Accounts Using IAM Roles</a> in the <i>IAM User
-     * Guide</i>.</p> <p>The <a href="http://wikipedia.org/wiki/regex">regex
-     * pattern</a> that is used to validate this parameter is a string of characters
-     * that can consist of uppercase letters, lowercase letters, digits with no spaces,
-     * and any of the following characters: =,.@-</p>
+     * Guide</i> </p> </li> </ul> <p>The <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a> that is used to
+     * validate this parameter. The pattern can include uppercase letters, lowercase
+     * letters, digits with no spaces, and any of the following characters: =,.@-</p>
      */
     inline CreateAccountRequest& WithRoleName(const char* value) { SetRoleName(value); return *this;}
 
@@ -406,6 +406,111 @@ namespace Model
      */
     inline CreateAccountRequest& WithIamUserAccessToBilling(IAMUserAccessToBilling&& value) { SetIamUserAccessToBilling(std::move(value)); return *this;}
 
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>A list of tags that you want to attach to the newly created account. For each
+     * tag in the list, you must specify both a tag key and a value. You can set the
+     * value to an empty string, but you can't set it to <code>null</code>. For more
+     * information about tagging, see <a
+     * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html">Tagging
+     * AWS Organizations resources</a> in the AWS Organizations User Guide.</p> 
+     * <p>If any one of the tags is invalid or if you exceed the allowed number of tags
+     * for an account, then the entire request fails and the account is not
+     * created.</p> 
+     */
+    inline CreateAccountRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_email;
@@ -419,6 +524,9 @@ namespace Model
 
     IAMUserAccessToBilling m_iamUserAccessToBilling;
     bool m_iamUserAccessToBillingHasBeenSet;
+
+    Aws::Vector<Tag> m_tags;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
