@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 """Generate burn in tests to run on certain build variants."""
-
 from collections import namedtuple
+import logging
 import os
 import sys
-from typing import Any, Dict, Iterable
+from typing import Any, Dict, List
 
 import click
 
@@ -22,14 +22,20 @@ import buildscripts.util.read_config as read_config
 from buildscripts.ciconfig import evergreen
 from buildscripts.ciconfig.evergreen import EvergreenProjectConfig, Variant
 from buildscripts.burn_in_tests import create_generate_tasks_config, create_tests_by_task, \
-    GenerateConfig, RepeatConfig, DEFAULT_REPO_LOCATIONS
+    find_changed_tests, GenerateConfig, RepeatConfig, DEFAULT_REPO_LOCATIONS
 # pylint: enable=wrong-import-position
 
+EXTERNAL_LOGGERS = {
+    "evergreen",
+    "git",
+    "urllib3",
+}
 CONFIG_DIRECTORY = "generated_burn_in_tags_config"
 CONFIG_FILE = "burn_in_tags_gen.json"
 EVERGREEN_FILE = "etc/evergreen.yml"
 EVG_CONFIG_FILE = ".evergreen.yml"
 COMPILE_TASK = "compile_without_package_TG"
+TASK_ID_EXPANSION = "task_id"
 
 ConfigOptions = namedtuple("ConfigOptions", [
     "build_variant",
@@ -120,10 +126,11 @@ def _generate_evg_build_variant(
     return build_variant
 
 
-# pylint: disable=too-many-arguments
+# pylint: disable=too-many-arguments,too-many-locals
 def _generate_evg_tasks(evergreen_api: EvergreenApi, shrub_project: ShrubProject,
                         task_expansions: Dict[str, Any], build_variant_map: Dict[str, str],
-                        repos: Iterable[Repo], evg_conf: EvergreenProjectConfig) -> None:
+                        repos: List[Repo], evg_conf: EvergreenProjectConfig,
+                        install_dir: str) -> None:
     """
     Generate burn in tests tasks for a given shrub config and group of build variants.
 
@@ -135,7 +142,9 @@ def _generate_evg_tasks(evergreen_api: EvergreenApi, shrub_project: ShrubProject
     """
     for build_variant, run_build_variant in build_variant_map.items():
         config_options = _get_config_options(task_expansions, build_variant, run_build_variant)
-        tests_by_task = create_tests_by_task(build_variant, repos, evg_conf)
+        task_id = task_expansions[TASK_ID_EXPANSION]
+        changed_tests = find_changed_tests(repos, evg_api=evergreen_api, task_id=task_id)
+        tests_by_task = create_tests_by_task(build_variant, evg_conf, changed_tests, install_dir)
         if tests_by_task:
             shrub_build_variant = _generate_evg_build_variant(
                 evg_conf.get_variant(build_variant), run_build_variant,
@@ -152,20 +161,47 @@ def _generate_evg_tasks(evergreen_api: EvergreenApi, shrub_project: ShrubProject
 
 
 def burn_in(task_expansions: Dict[str, Any], evg_conf: EvergreenProjectConfig,
-            evergreen_api: RetryingEvergreenApi, repos: Iterable[Repo]):
-    """Execute Main program."""
+            evergreen_api: RetryingEvergreenApi, repos: List[Repo], install_dir: str):
+    """
+    Execute main program.
+
+    :param task_expansions: Dictionary of expansions for the running task.
+    :param evg_conf: Evergreen configuration.
+    :param evergreen_api: Evergreen.py object.
+    :param repos: Git repositories.
+    :param install_dir: path to bin directory of a testable installation
+    """
     shrub_project = ShrubProject.empty()
     build_variant_map = _create_evg_build_variant_map(task_expansions, evg_conf)
     _generate_evg_tasks(evergreen_api, shrub_project, task_expansions, build_variant_map, repos,
-                        evg_conf)
+                        evg_conf, install_dir)
 
     write_file_to_dir(CONFIG_DIRECTORY, CONFIG_FILE, shrub_project.json())
 
 
+def _configure_logging(verbose: bool):
+    """
+    Configure logging for the application.
+
+    :param verbose: If True set log level to DEBUG.
+    """
+    level = logging.DEBUG if verbose else logging.INFO
+    logging.basicConfig(
+        format="[%(asctime)s - %(name)s - %(levelname)s] %(message)s",
+        level=level,
+        stream=sys.stdout,
+    )
+    for log_name in EXTERNAL_LOGGERS:
+        logging.getLogger(log_name).setLevel(logging.WARNING)
+
+
 @click.command()
 @click.option("--expansion-file", "expansion_file", required=True,
               help="Location of expansions file generated by evergreen.")
-def main(expansion_file: str):
+@click.option("--verbose", is_flag=True)
+@click.option("--install-dir", "install_dir", required=True,
+              help="Path to bin directory of a testable installation")
+def main(expansion_file: str, verbose: bool, install_dir: str):
     """
     Run new or changed tests in repeated mode to validate their stability.
 
@@ -175,12 +211,13 @@ def main(expansion_file: str):
     \f
     :param expansion_file: The expansion file containing the configuration params.
     """
+    _configure_logging(verbose)
     evg_api = RetryingEvergreenApi.get_api(config_file=EVG_CONFIG_FILE)
     repos = [Repo(x) for x in DEFAULT_REPO_LOCATIONS if os.path.isdir(x)]
     expansions_file_data = read_config.read_config_file(expansion_file)
     evg_conf = evergreen.parse_evergreen_file(EVERGREEN_FILE)
 
-    burn_in(expansions_file_data, evg_conf, evg_api, repos)
+    burn_in(expansions_file_data, evg_conf, evg_api, repos, install_dir)
 
 
 if __name__ == "__main__":
