@@ -9,7 +9,7 @@ import subprocess
 import sys
 from collections import defaultdict
 from math import ceil
-from typing import Optional, Set, Tuple, List, Dict, Iterable
+from typing import Optional, Set, Tuple, List, Dict
 
 import click
 import requests
@@ -26,17 +26,19 @@ if __name__ == "__main__" and __package__ is None:
     sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 # pylint: disable=wrong-import-position
-from buildscripts.patch_builds.change_data import find_changed_files_in_repos
+from buildscripts.patch_builds.change_data import generate_revision_map, \
+    generate_revision_map_from_manifest, RevisionMap, find_changed_files_in_repos
 import buildscripts.resmokelib.parser
 from buildscripts.resmokelib.suitesconfig import create_test_membership_map, get_suites
 from buildscripts.resmokelib.utils import default_if_none, globstar
 from buildscripts.ciconfig.evergreen import parse_evergreen_file, ResmokeArgs, \
     EvergreenProjectConfig, VariantTask
 from buildscripts.util.fileops import write_file
-from buildscripts.util.teststats import TestStats
+from buildscripts.util.teststats import HistoricTaskData, TestRuntime
 from buildscripts.util.taskname import name_generated_task
 from buildscripts.patch_builds.task_generation import (resmoke_commands, TimeoutInfo,
                                                        validate_task_generation_limit)
+
 # pylint: enable=wrong-import-position
 
 structlog.configure(logger_factory=LoggerFactory())
@@ -52,7 +54,8 @@ AVG_TEST_SETUP_SEC = 4 * 60
 AVG_TEST_TIME_MULTIPLIER = 3
 CONFIG_FILE = ".evergreen.yml"
 DEFAULT_PROJECT = "mongodb-mongo-master"
-DEFAULT_REPO_LOCATIONS = [".", "./src/mongo/db/modules/enterprise"]
+ENTERPRISE_MODULE_PATH = "src/mongo/db/modules/enterprise"
+DEFAULT_REPO_LOCATIONS = [".", f"./{ENTERPRISE_MODULE_PATH}"]
 REPEAT_SUITES = 2
 EVERGREEN_FILE = "etc/evergreen.yml"
 MIN_AVG_TEST_OVERFLOW_SEC = float(60)
@@ -200,7 +203,29 @@ def is_file_a_test_file(file_path: str) -> bool:
     return True
 
 
-def find_changed_tests(repos: Iterable[Repo]) -> Set[str]:
+def _create_revision_map(repos: List[Repo], origin_rev: Optional[str], evg_api: EvergreenApi,
+                         task_id: Optional[str]) -> RevisionMap:
+    """
+    Create a map of the repos and the given revisions to diff against.
+
+    :param repos: Repositories to include in the map.
+    :param origin_rev: User specified revision to compare against.
+    :param evg_api: Evergreen API client.
+    :param task_id: Evergreen task ID.
+    :return: Map of repositories to revisions.
+    """
+    if origin_rev:
+        return generate_revision_map(repos, {"mongo": origin_rev})
+
+    if evg_api and task_id:
+        return generate_revision_map_from_manifest(repos, task_id, evg_api)
+
+    return {}
+
+
+def find_changed_tests(repos: List[Repo], origin_rev: Optional[str] = None,
+                       evg_api: Optional[EvergreenApi] = None,
+                       task_id: Optional[str] = None) -> Set[str]:
     """
     Find the changed tests.
 
@@ -208,9 +233,14 @@ def find_changed_tests(repos: Iterable[Repo]) -> Set[str]:
     The returned file paths are in normalized form (see os.path.normpath(path)).
 
     :param repos: List of repos containing changed files.
-    :returns: Set of changed tests.
+    :param origin_rev: The revision that local changes will be compared against.
+    :param evg_api: Evergreen API client.
+    :param task_id: Evergreen task ID.
+    :return: Set of changed tests.
     """
-    changed_files = find_changed_files_in_repos(repos)
+    revision_map = _create_revision_map(repos, origin_rev, evg_api, task_id)
+    LOGGER.info("Calculated revision map", revision_map=revision_map)
+    changed_files = find_changed_files_in_repos(repos, revision_map)
     return {os.path.normpath(path) for path in changed_files if is_file_a_test_file(path)}
 
 
@@ -234,7 +264,7 @@ def find_excludes(selector_file: str) -> Tuple[List, List, List]:
             default_if_none(js_test.get("exclude_tests"), []))
 
 
-def filter_tests(tests: Set[str], exclude_tests: [str]) -> Set[str]:
+def filter_tests(tests: Set[str], exclude_tests: List[str]) -> Set[str]:
     """
     Exclude tests which have been blacklisted.
 
@@ -406,11 +436,12 @@ def _set_resmoke_cmd(repeat_config: RepeatConfig, resmoke_args: [str]) -> [str]:
     return new_args
 
 
-def _parse_avg_test_runtime(test: str, task_avg_test_runtime_stats: [TestStats]) -> Optional[float]:
+def _parse_avg_test_runtime(test: str,
+                            task_avg_test_runtime_stats: List[TestRuntime]) -> Optional[float]:
     """
-    Parse list of teststats to find runtime for particular test.
+    Parse list of test runtimes to find runtime for particular test.
 
-    :param task_avg_test_runtime_stats: Teststat data.
+    :param task_avg_test_runtime_stats: List of average historic runtimes of tests.
     :param test: Test name.
     :return: Historical average runtime of the test.
     """
@@ -456,13 +487,13 @@ def _calculate_exec_timeout(repeat_config: RepeatConfig, avg_test_runtime: float
 
 
 def _generate_timeouts(repeat_config: RepeatConfig, test: str,
-                       task_avg_test_runtime_stats: [TestStats]) -> TimeoutInfo:
+                       task_avg_test_runtime_stats: [TestRuntime]) -> TimeoutInfo:
     """
     Add timeout.update command to list of commands for a burn in execution task.
 
     :param repeat_config: Information on how the test will repeat.
     :param test: Test name.
-    :param task_avg_test_runtime_stats: Teststat data.
+    :param task_avg_test_runtime_stats: Average historic runtimes of tests.
     :return: TimeoutInfo to use.
     """
     if task_avg_test_runtime_stats:
@@ -482,7 +513,7 @@ def _generate_timeouts(repeat_config: RepeatConfig, test: str,
 
 
 def _get_task_runtime_history(evg_api: Optional[EvergreenApi], project: str, task: str,
-                              variant: str):
+                              variant: str) -> List[TestRuntime]:
     """
     Fetch historical average runtime for all tests in a task from Evergreen API.
 
@@ -498,12 +529,9 @@ def _get_task_runtime_history(evg_api: Optional[EvergreenApi], project: str, tas
     try:
         end_date = datetime.datetime.utcnow().replace(microsecond=0)
         start_date = end_date - datetime.timedelta(days=AVG_TEST_RUNTIME_ANALYSIS_DAYS)
-        data = evg_api.test_stats_by_project(project, after_date=start_date.strftime("%Y-%m-%d"),
-                                             before_date=end_date.strftime("%Y-%m-%d"),
-                                             tasks=[task], variants=[variant], group_by="test",
-                                             group_num_days=AVG_TEST_RUNTIME_ANALYSIS_DAYS)
-        test_runtimes = TestStats(data).get_tests_runtimes()
-        return test_runtimes
+        test_stats = HistoricTaskData.from_evg(evg_api, project, start_date=start_date,
+                                               end_date=end_date, task=task, variant=variant)
+        return test_stats.get_tests_runtimes()
     except requests.HTTPError as err:
         if err.response.status_code == requests.codes.SERVICE_UNAVAILABLE:
             # Evergreen may return a 503 when the service is degraded.
@@ -514,7 +542,7 @@ def _get_task_runtime_history(evg_api: Optional[EvergreenApi], project: str, tas
 
 
 def _create_task(index: int, test_count: int, test: str, task_data: Dict,
-                 task_runtime_stats: List[TestStats], generate_config: GenerateConfig,
+                 task_runtime_stats: List[TestRuntime], generate_config: GenerateConfig,
                  repeat_config: RepeatConfig, task_prefix: str) -> Task:
     # pylint: disable=too-many-arguments,too-many-locals
     """
@@ -629,22 +657,22 @@ def create_task_list_for_tests(
     return create_task_list(evg_conf, build_variant, tests_by_executor, exclude_tasks)
 
 
-def create_tests_by_task(build_variant: str, repos: Iterable[Repo],
-                         evg_conf: EvergreenProjectConfig) -> Dict:
+def create_tests_by_task(build_variant: str, evg_conf: EvergreenProjectConfig,
+                         changed_tests: Set[str], install_dir: str) -> Dict:
     """
     Create a list of tests by task.
 
     :param build_variant: Build variant to collect tasks from.
-    :param repos: Git repositories being tracked.
     :param evg_conf: Evergreen configuration.
+    :param changed_tests: Set of changed test files.
     :return: Tests by task.
     """
-    changed_tests = find_changed_tests(repos)
-    LOGGER.debug("Found changed tests", files=changed_tests)
     exclude_suites, exclude_tasks, exclude_tests = find_excludes(SELECTOR_FILE)
+    if not evg_conf.get_variant(build_variant).is_enterprise_build():
+        exclude_tests.append(f"{ENTERPRISE_MODULE_PATH}/**/*")
     changed_tests = filter_tests(changed_tests, exclude_tests)
 
-    buildscripts.resmokelib.parser.set_run_options()
+    buildscripts.resmokelib.parser.set_run_options(f"--installDir={shlex.quote(install_dir)}")
     if changed_tests:
         return create_task_list_for_tests(changed_tests, build_variant, evg_conf, exclude_suites,
                                           exclude_tasks)
@@ -735,7 +763,8 @@ def _get_evg_api(evg_api_config: str, local_mode: bool) -> Optional[EvergreenApi
 
 def burn_in(repeat_config: RepeatConfig, generate_config: GenerateConfig, resmoke_args: str,
             generate_tasks_file: str, no_exec: bool, evg_conf: EvergreenProjectConfig,
-            repos: Iterable[Repo], evg_api: EvergreenApi) -> None:
+            repos: List[Repo], evg_api: EvergreenApi, origin_rev: Optional[str],
+            install_dir: str) -> None:
     """
     Run burn_in_tests with the given configuration.
 
@@ -747,11 +776,17 @@ def burn_in(repeat_config: RepeatConfig, generate_config: GenerateConfig, resmok
     :param evg_conf: Evergreen configuration.
     :param repos: Git repositories to check.
     :param evg_api: Evergreen API client.
+    :param project: Evergreen project to query.
+    :param origin_rev: The revision that local changes will be compared against.
     """
+    changed_tests = find_changed_tests(repos, origin_rev, evg_api, generate_config.task_id)
+    LOGGER.info("Found changed tests", files=changed_tests)
+
     # Populate the config values in order to use the helpers from resmokelib.suitesconfig.
     resmoke_cmd = _set_resmoke_cmd(repeat_config, list(resmoke_args))
 
-    tests_by_task = create_tests_by_task(generate_config.build_variant, repos, evg_conf)
+    tests_by_task = create_tests_by_task(generate_config.build_variant, evg_conf, changed_tests,
+                                         install_dir)
     LOGGER.debug("tests and tasks found", tests_by_task=tests_by_task)
 
     if generate_tasks_file:
@@ -764,6 +799,7 @@ def burn_in(repeat_config: RepeatConfig, generate_config: GenerateConfig, resmok
         LOGGER.info("Not running tests due to 'no_exec' option.")
 
 
+# pylint: disable=too-many-function-args
 @click.command()
 @click.option("--no-exec", "no_exec", default=False, is_flag=True,
               help="Do not execute the found tests.")
@@ -792,17 +828,28 @@ def burn_in(repeat_config: RepeatConfig, generate_config: GenerateConfig, resmok
 @click.option("--verbose", "verbose", default=False, is_flag=True, help="Enable extra logging.")
 @click.option("--task_id", "task_id", default=None, metavar='TASK_ID',
               help="The evergreen task id.")
+@click.option(
+    "--origin-rev", "origin_rev", default=None,
+    help="The revision in the mongo repo that changes will be compared against if specified.")
+@click.option("--install-dir", "install_dir", required=True, type=str,
+              help="Path to bin directory of a testable installation")
 @click.argument("resmoke_args", nargs=-1, type=click.UNPROCESSED)
 # pylint: disable=too-many-arguments,too-many-locals
 def main(build_variant, run_build_variant, distro, project, generate_tasks_file, no_exec,
          repeat_tests_num, repeat_tests_min, repeat_tests_max, repeat_tests_secs, resmoke_args,
-         local_mode, evg_api_config, verbose, task_id):
+         local_mode, evg_api_config, verbose, task_id, origin_rev, install_dir: str):
     """
     Run new or changed tests in repeated mode to validate their stability.
 
     burn_in_tests detects jstests that are new or changed since the last git command and then
     runs those tests in a loop to validate their reliability.
 
+    The `--origin-rev` argument allows users to specify which revision should be used as the last
+    git command to compare against to find changed files. If the `--origin-rev` argument is provided,
+    we find changed files by comparing your latest changes to this revision. If not provided, we
+    find changed test files by comparing your latest changes to HEAD. The revision provided must
+    be a revision that exists in the mongodb repository.
+
     The `--repeat-*` arguments allow configuration of how burn_in_tests repeats tests. Tests can
     either be repeated a specified number of times with the `--repeat-tests` option, or they can
     be repeated for a certain time period with the `--repeat-tests-secs` option.
@@ -837,6 +884,8 @@ def main(build_variant, run_build_variant, distro, project, generate_tasks_file,
     :param local_mode: Don't call out to the evergreen API (used for testing).
     :param evg_api_config: Location of configuration file to connect to evergreen.
     :param verbose: Log extra debug information.
+    :param task_id: Id of evergreen task being run in.
+    :param origin_rev: The revision that local changes will be compared against.
     """
     _configure_logging(verbose)
 
@@ -858,7 +907,7 @@ def main(build_variant, run_build_variant, distro, project, generate_tasks_file,
     repos = [Repo(x) for x in DEFAULT_REPO_LOCATIONS if os.path.isdir(x)]
 
     burn_in(repeat_config, generate_config, resmoke_args, generate_tasks_file, no_exec, evg_conf,
-            repos, evg_api)
+            repos, evg_api, origin_rev, install_dir)
 
 
 if __name__ == "__main__":
