@@ -4,8 +4,11 @@ import collections
 import os
 import os.path
 import sys
-import shlex
 import configparser
+import random
+import glob
+import textwrap
+import shlex
 
 from typing import NamedTuple
 
@@ -47,8 +50,12 @@ def _validate_options(parser, args):
         errors = []
         for key, values in agg_set_params.items():
             if len(values) > 1:
-                errors.append(f"setParameter has multiple values. Key: {key} Values: {values}")
-
+                for left, _ in enumerate(values):
+                    for right in range(left + 1, len(values)):
+                        if values[left] != values[right]:
+                            errors.append(
+                                f"setParameter has multiple distinct values. Key: {key} Values: {values}"
+                            )
         return errors
 
     config = vars(args)
@@ -86,6 +93,19 @@ def _validate_config(parser):  # pylint: disable=too-many-branches
                              " 'version1-version2'")
 
 
+def _find_resmoke_wrappers():
+    # This is technically incorrect. PREFIX_BINDIR defaults to $PREFIX/bin, so
+    # if the user changes it to any some other value, this glob will fail to
+    # detect the resmoke wrapper.
+    # Additionally, the resmoke wrapper will not be found if a user performs
+    # their builds outside of the git repository root, (ex checkout at
+    # /data/mongo, build-dir at /data/build)
+    # We assume that users who fall under either case will explicitly pass the
+    # --installDir argument.
+    candidate_installs = glob.glob("**/bin/resmoke.py", recursive=True)
+    return list(candidate_installs)
+
+
 def _update_config_vars(values):  # pylint: disable=too-many-statements,too-many-locals,too-many-branches
     """Update the variables of the config module."""
 
@@ -100,12 +120,26 @@ def _update_config_vars(values):  # pylint: disable=too-many-statements,too-many
         if cmdline_vars[cmdline_key] is not None:
             config[cmdline_key] = cmdline_vars[cmdline_key]
 
-    if os.path.isfile("resmoke.ini"):
+    if values.command == "run" and os.path.isfile("resmoke.ini"):
+        err = textwrap.dedent("""\
+Support for resmoke.ini has been removed. You must delete
+resmoke.ini and rerun your build to run resmoke. If only one testable
+installation is present, resmoke will automatically locate that installation.
+If you have multiple installations, you must either pass an explicit
+--installDir argument to the run subcommand to identify the installation you
+would like to test, or invoke the customized resmoke.py wrapper script staged
+into the bin directory of each installation.""")
         config_parser = configparser.ConfigParser()
         config_parser.read("resmoke.ini")
         if "resmoke" in config_parser.sections():
             user_config = dict(config_parser["resmoke"])
-            config.update(user_config)
+            err += textwrap.dedent(f"""
+
+Based on the current value of resmoke.ini, after rebuilding, resmoke.py should
+be invoked as either:
+- {shlex.quote(f"{user_config['install_dir']}/resmoke.py")}
+- buildscripts/resmoke.py --installDir {shlex.quote(user_config['install_dir'])}""")
+        raise RuntimeError(err)
 
     _config.ALWAYS_USE_LOG_FILES = config.pop("always_use_log_files")
     _config.ARCHIVE_FILE = config.pop("archive_file")
@@ -130,6 +164,18 @@ def _update_config_vars(values):  # pylint: disable=too-many-statements,too-many
         _config.MIXED_BIN_VERSIONS = _config.MIXED_BIN_VERSIONS.split("-")
 
     _config.INSTALL_DIR = config.pop("install_dir")
+    if values.command == "run" and _config.INSTALL_DIR is None:
+        resmoke_wrappers = _find_resmoke_wrappers()
+        if len(resmoke_wrappers) == 1:
+            _config.INSTALL_DIR = os.path.dirname(resmoke_wrappers[0])
+        elif len(resmoke_wrappers) > 1:
+            err = textwrap.dedent(f"""\
+Multiple testable installations were found, but installDir was not specified.
+You must either call resmoke via one of the following scripts:
+{os.linesep.join(map(shlex.quote, resmoke_wrappers))}
+
+or explicitly pass --installDir to the run subcommand of buildscripts/resmoke.py.""")
+            raise RuntimeError(err)
     if _config.INSTALL_DIR is not None:
         # Normalize the path so that on Windows dist-test/bin
         # translates to .\dist-test\bin then absolutify it since the
@@ -198,6 +244,20 @@ def _update_config_vars(values):  # pylint: disable=too-many-statements,too-many
     # Archival options. Archival is enabled only when running on evergreen.
     if not _config.EVERGREEN_TASK_ID:
         _config.ARCHIVE_FILE = None
+    else:
+        required_builder_names = set([
+            "ubuntu1804-debug-aubsan-lite",
+            "linux-64-debug",
+            "enterprise-windows-required",
+            "enterprise-rhel-62-64-bit",
+            "enterprise-ubuntu-dynamic-1604-clang",
+        ])
+        # Enable archival globally for all required mainline builders.
+        if (_config.EVERGREEN_VARIANT_NAME is not None
+                and _config.EVERGREEN_VARIANT_NAME in required_builder_names
+                and not _config.EVERGREEN_PATCH_BUILD):
+            _config.FORCE_ARCHIVE_ALL_DATA_FILES = True
+
     _config.ARCHIVE_LIMIT_MB = config.pop("archive_limit_mb")
     _config.ARCHIVE_LIMIT_TESTS = config.pop("archive_limit_tests")
 
