@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 import collections
 import datetime
+import json
 import os
 import sys
 import subprocess
@@ -12,20 +13,24 @@ import unittest
 from math import ceil
 from mock import Mock, patch, MagicMock
 
-from shrub.config import Configuration
+import requests
+
+from shrub.v2 import ShrubProject, BuildVariant
 
 import buildscripts.burn_in_tests as under_test
 from buildscripts.ciconfig.evergreen import parse_evergreen_file
 import buildscripts.util.teststats as teststats_utils
+import buildscripts.resmokelib.parser as _parser
 import buildscripts.resmokelib.config as _config
+_parser.set_run_options()
 
 # pylint: disable=missing-docstring,protected-access,too-many-lines,no-self-use
 
 
 def create_tests_by_task_mock(n_tasks, n_tests):
     return {
-        f"task_{i}": {
-            "resmoke_args": f"--suites=suite_{i}",
+        f"task_{i}_gen": {
+            "display_task_name": f"task_{i}", "resmoke_args": f"--suites=suite_{i}",
             "tests": [f"jstests/tests_{j}" for j in range(n_tests)]
         }
         for i in range(n_tasks)
@@ -34,18 +39,6 @@ def create_tests_by_task_mock(n_tasks, n_tests):
 
 MV_MOCK_SUITES = ["replica_sets_jscore_passthrough", "sharding_jscore_passthrough"]
 
-
-def create_multiversion_tests_by_task_mock(n_tasks, n_tests):
-    assert n_tasks <= len(MV_MOCK_SUITES)
-    return {
-        f"{MV_MOCK_SUITES[i % len(MV_MOCK_SUITES)]}": {
-            "resmoke_args": f"--suites=suite_{i}",
-            "tests": [f"jstests/tests_{j}" for j in range(n_tests)]
-        }
-        for i in range(n_tasks)
-    }
-
-
 _DATE = datetime.datetime(2018, 7, 15)
 RESMOKELIB = "buildscripts.resmokelib"
 
@@ -71,6 +64,7 @@ def mock_git_diff(change_list):
 def mock_changed_git_files(add_files):
     repo = MagicMock()
     repo.index.diff.return_value = mock_git_diff([mock_a_file(f) for f in add_files])
+    repo.working_dir = "."
     return repo
 
 
@@ -82,39 +76,40 @@ def get_evergreen_config(config_file_path):
 
 
 class TestAcceptance(unittest.TestCase):
-    @patch(ns("_write_json_file"))
-    @patch(ns("get_stats_from_s3"))
-    def test_no_tests_run_if_none_changed(self, get_stats_from_s3_mock, write_json_mock):
+    def tearDown(self):
+        _parser.set_run_options()
+
+    @patch(ns("write_file"))
+    def test_no_tests_run_if_none_changed(self, write_json_mock):
         """
         Given a git repository with no changes,
         When burn_in_tests is run,
         Then no tests are discovered to run.
         """
         variant = "build_variant"
-        repo = mock_changed_git_files([])
+        repos = [mock_changed_git_files([])]
         repeat_config = under_test.RepeatConfig()
         gen_config = under_test.GenerateConfig(
             variant,
             "project",
         )  # yapf: disable
-        get_stats_from_s3_mock.return_value = []
 
-        under_test.burn_in(repeat_config, gen_config, "", "testfile.json", False, None, repo)
+        under_test.burn_in(repeat_config, gen_config, "", "testfile.json", False, MagicMock(),
+                           repos, None, None, 'install_dir/bin')
 
         write_json_mock.assert_called_once()
-        written_config = write_json_mock.call_args[0][0]
+        written_config = json.loads(write_json_mock.call_args[0][1])
         display_task = written_config["buildvariants"][0]["display_tasks"][0]
         self.assertEqual(1, len(display_task["execution_tasks"]))
         self.assertEqual(under_test.BURN_IN_TESTS_GEN_TASK, display_task["execution_tasks"][0])
 
     @unittest.skipIf(sys.platform.startswith("win"), "not supported on windows")
-    @patch(ns("_write_json_file"))
-    @patch(ns("get_stats_from_s3"))
-    def test_tests_generated_if_a_file_changed(self, get_stats_from_s3_mock, write_json_mock):
+    @patch(ns("write_file"))
+    def test_tests_generated_if_a_file_changed(self, write_json_mock):
         """
-        Given a git repository with no changes,
+        Given a git repository with changes,
         When burn_in_tests is run,
-        Then no tests are discovered to run.
+        Then tests are discovered to run.
         """
         # Note: this test is using actual tests and suites. So changes to those suites could
         # introduce failures and require this test to be updated.
@@ -122,19 +117,19 @@ class TestAcceptance(unittest.TestCase):
         # 'auth_audit' test suites. It needs to be in at least one of those for the test to pass.
         _config.NAMED_SUITES = None
         variant = "enterprise-rhel-62-64-bit"
-        repo = mock_changed_git_files(["jstests/auth/auth1.js"])
+        repos = [mock_changed_git_files(["jstests/auth/auth1.js"])]
         repeat_config = under_test.RepeatConfig()
         gen_config = under_test.GenerateConfig(
             variant,
             "project",
         )  # yapf: disable
         evg_config = get_evergreen_config("etc/evergreen.yml")
-        get_stats_from_s3_mock.return_value = []
 
-        under_test.burn_in(repeat_config, gen_config, "", "testfile.json", False, evg_config, repo)
+        under_test.burn_in(repeat_config, gen_config, "", "testfile.json", False, evg_config, repos,
+                           None, None, 'install_dir/bin')
 
         write_json_mock.assert_called_once()
-        written_config = write_json_mock.call_args[0][0]
+        written_config = json.loads(write_json_mock.call_args[0][1])
         n_tasks = len(written_config["tasks"])
         # Ensure we are generating at least one task for the test.
         self.assertGreaterEqual(n_tasks, 1)
@@ -184,7 +179,7 @@ class TestRepeatConfig(unittest.TestCase):
         repeat_config = under_test.RepeatConfig(repeat_tests_num=5)
         repeat_options = repeat_config.generate_resmoke_options()
 
-        self.assertEqual(repeat_options.strip(), "--repeatSuites=5")
+        self.assertEqual(repeat_options.strip(), f"--repeatSuites=5")
 
     def test_get_resmoke_repeat_options_secs(self):
         repeat_config = under_test.RepeatConfig(repeat_tests_secs=5)
@@ -266,12 +261,6 @@ class TestGenerateConfig(unittest.TestCase):
         gen_config = under_test.GenerateConfig("build_variant", "project")
         gen_config.validate(evg_conf_mock)
 
-    def test_validate_use_multiversion(self):
-        evg_conf_mock = MagicMock()
-
-        gen_config = under_test.GenerateConfig("build_variant", "project")
-        gen_config.validate(evg_conf_mock)
-
 
 class TestParseAvgTestRuntime(unittest.TestCase):
     def test__parse_avg_test_runtime(self):
@@ -349,26 +338,44 @@ class TestGenerateTimeouts(unittest.TestCase):
 
 
 class TestGetTaskRuntimeHistory(unittest.TestCase):
-    @patch(ns("get_stats_from_s3"))
-    def test__get_task_runtime_history(self, get_stats_from_s3_mock):
-        test_stats = [
-            teststats_utils.HistoricalTestInformation(
-                test_name="dir/test2.js",
+    def test_get_task_runtime_history_with_no_api(self):
+        self.assertListEqual([],
+                             under_test._get_task_runtime_history(None, "project", "task",
+                                                                  "variant"))
+
+    def test__get_task_runtime_history(self):
+        evergreen_api = Mock()
+        evergreen_api.test_stats_by_project.return_value = [
+            Mock(
+                test_file="dir/test2.js",
+                task_name="task1",
+                variant="variant1",
+                distro="distro1",
+                date=_DATE,
                 num_pass=1,
                 num_fail=0,
                 avg_duration_pass=10.1,
             )
         ]
-        get_stats_from_s3_mock.return_value = test_stats
+        analysis_duration = under_test.AVG_TEST_RUNTIME_ANALYSIS_DAYS
+        end_date = datetime.datetime.utcnow().replace(microsecond=0)
+        start_date = end_date - datetime.timedelta(days=analysis_duration)
 
-        result = under_test._get_task_runtime_history("project1", "task1", "variant1")
+        result = under_test._get_task_runtime_history(evergreen_api, "project1", "task1",
+                                                      "variant1")
         self.assertEqual(result, [("dir/test2.js", 10.1)])
+        evergreen_api.test_stats_by_project.assert_called_with(
+            "project1", after_date=start_date, before_date=end_date, group_by="test",
+            group_num_days=14, tasks=["task1"], variants=["variant1"])
 
-    @patch(ns("get_stats_from_s3"))
-    def test__get_task_runtime_history_when_s3_has_no_data(self, get_stats_from_s3_mock):  # pylint: disable=invalid-name
-        get_stats_from_s3_mock.return_value = []
+    def test__get_task_runtime_history_evg_degraded_mode_error(self):  # pylint: disable=invalid-name
+        response = Mock()
+        response.status_code = requests.codes.SERVICE_UNAVAILABLE
+        evergreen_api = Mock()
+        evergreen_api.test_stats_by_project.side_effect = requests.HTTPError(response=response)
 
-        result = under_test._get_task_runtime_history("project1", "task1", "variant1")
+        result = under_test._get_task_runtime_history(evergreen_api, "project1", "task1",
+                                                      "variant1")
         self.assertEqual(result, [])
 
 
@@ -390,7 +397,7 @@ class TestSetResmokeArgs(unittest.TestCase):
     def test__set_resmoke_args(self):
         resmoke_args = "--suites=suite1 test1.js"
         task = Mock()
-        task.resmoke_args = resmoke_args
+        task.combined_resmoke_args = resmoke_args
         task.is_generate_resmoke_task = False
         self.assertEqual(resmoke_args, under_test._set_resmoke_args(task))
 
@@ -399,7 +406,7 @@ class TestSetResmokeArgs(unittest.TestCase):
         new_suite = "suite2"
         new_resmoke_args = "--suites={} test1.js".format(new_suite)
         task = Mock()
-        task.resmoke_args = resmoke_args
+        task.combined_resmoke_args = resmoke_args
         task.is_generate_resmoke_task = True
         task.get_vars_suite_name = lambda cmd_vars: cmd_vars["suite"]
         task.generate_resmoke_tasks_command = {"vars": {"suite": new_suite}}
@@ -409,7 +416,7 @@ class TestSetResmokeArgs(unittest.TestCase):
         suite = "suite1"
         resmoke_args = "--suites={} test1.js".format(suite)
         task = Mock()
-        task.resmoke_args = resmoke_args
+        task.combined_resmoke_args = resmoke_args
         task.is_generate_resmoke_task = True
         task.get_vars_suite_name = lambda cmd_vars: cmd_vars["task"]
         task.generate_resmoke_tasks_command = {"vars": {"task": suite}}
@@ -453,43 +460,37 @@ TESTS_BY_TASK = {
         "tests": ["jstests/test4.js", "jstests/test5.js"]},
     "task4": {
         "resmoke_args": "--suites=suite4", "tests": []},
-    "taskmulti": {
-        "resmoke_args": "--suites=suite4",
-        "tests": ["jstests/multi1.js"],
-        "use_multiversion": "/data/multi"},
 }  # yapf: disable
 
 
 class TestCreateGenerateTasksConfig(unittest.TestCase):
-    @patch(ns("get_stats_from_s3"))
-    def test_no_tasks_given(self, get_stats_from_s3_mock):
-        evg_config = Configuration()
+    @unittest.skipIf(sys.platform.startswith("win"), "not supported on windows")
+    def test_no_tasks_given(self):
+        build_variant = BuildVariant("build variant")
         gen_config = MagicMock(run_build_variant="variant")
         repeat_config = MagicMock()
-        get_stats_from_s3_mock.return_value = []
 
-        evg_config = under_test.create_generate_tasks_config(evg_config, {}, gen_config,
-                                                             repeat_config)
+        under_test.create_generate_tasks_config(build_variant, {}, gen_config, repeat_config, None)
 
-        evg_config_dict = evg_config.to_map()
-        self.assertNotIn("tasks", evg_config_dict)
+        evg_config_dict = build_variant.as_dict()
+        self.assertEqual(0, len(evg_config_dict["tasks"]))
 
-    @patch(ns("get_stats_from_s3"))
-    def test_one_task_one_test(self, get_stats_from_s3_mock):
+    @unittest.skipIf(sys.platform.startswith("win"), "not supported on windows")
+    def test_one_task_one_test(self):
         n_tasks = 1
         n_tests = 1
         resmoke_options = "options for resmoke"
-        evg_config = Configuration()
+        build_variant = BuildVariant("build variant")
         gen_config = MagicMock(run_build_variant="variant", distro=None)
         repeat_config = MagicMock()
         repeat_config.generate_resmoke_options.return_value = resmoke_options
         tests_by_task = create_tests_by_task_mock(n_tasks, n_tests)
-        get_stats_from_s3_mock.return_value = []
 
-        evg_config = under_test.create_generate_tasks_config(evg_config, tests_by_task, gen_config,
-                                                             repeat_config)
+        under_test.create_generate_tasks_config(build_variant, tests_by_task, gen_config,
+                                                repeat_config, None)
 
-        evg_config_dict = evg_config.to_map()
+        shrub_config = ShrubProject.empty().add_build_variant(build_variant)
+        evg_config_dict = shrub_config.as_dict()
         tasks = evg_config_dict["tasks"]
         self.assertEqual(n_tasks * n_tests, len(tasks))
         cmd = tasks[0]["commands"]
@@ -497,114 +498,34 @@ class TestCreateGenerateTasksConfig(unittest.TestCase):
         self.assertIn("--suites=suite_0", cmd[1]["vars"]["resmoke_args"])
         self.assertIn("tests_0", cmd[1]["vars"]["resmoke_args"])
 
-    @patch(ns("get_stats_from_s3"))
-    def test_n_task_m_test(self, get_stats_from_s3_mock):
+    @unittest.skipIf(sys.platform.startswith("win"), "not supported on windows")
+    def test_n_task_m_test(self):
         n_tasks = 3
         n_tests = 5
-        evg_config = Configuration()
+        build_variant = BuildVariant("build variant")
         gen_config = MagicMock(run_build_variant="variant", distro=None)
         repeat_config = MagicMock()
         tests_by_task = create_tests_by_task_mock(n_tasks, n_tests)
-        get_stats_from_s3_mock.return_value = []
 
-        evg_config = under_test.create_generate_tasks_config(evg_config, tests_by_task, gen_config,
-                                                             repeat_config)
+        under_test.create_generate_tasks_config(build_variant, tests_by_task, gen_config,
+                                                repeat_config, None)
 
-        evg_config_dict = evg_config.to_map()
+        evg_config_dict = build_variant.as_dict()
         self.assertEqual(n_tasks * n_tests, len(evg_config_dict["tasks"]))
 
-    @patch(ns("get_stats_from_s3"))
-    def test_multiversion_path_is_used(self, get_stats_from_s3_mock):
-        n_tasks = 1
-        n_tests = 1
-        evg_config = Configuration()
-        gen_config = MagicMock(run_build_variant="variant", distro=None)
-        repeat_config = MagicMock()
-        tests_by_task = create_tests_by_task_mock(n_tasks, n_tests)
-        first_task = "task_0"
-        multiversion_path = "multiversion_path"
-        tests_by_task[first_task]["use_multiversion"] = multiversion_path
-        get_stats_from_s3_mock.return_value = []
-
-        evg_config = under_test.create_generate_tasks_config(evg_config, tests_by_task, gen_config,
-                                                             repeat_config)
-
-        evg_config_dict = evg_config.to_map()
-        tasks = evg_config_dict["tasks"]
-        self.assertEqual(n_tasks * n_tests, len(tasks))
-        self.assertEqual(multiversion_path, tasks[0]["commands"][2]["vars"]["task_path_suffix"])
-
 
 class TestCreateGenerateTasksFile(unittest.TestCase):
-    @patch("buildscripts.burn_in_tests.create_generate_tasks_config")
-    def test_gen_tasks_configuration_is_returned(self, gen_tasks_config_mock):
-        evg_api = MagicMock()
-        gen_config = MagicMock(use_multiversion=False)
-        repeat_config = MagicMock()
-        tests_by_task = MagicMock()
-
-        task_list = [f"task_{i}" for i in range(10)]
-
-        evg_config = MagicMock()
-        evg_config.to_map.return_value = {
-            "tasks": task_list,
-        }
-
-        gen_tasks_config_mock.return_value = evg_config
-
-        config = under_test.create_generate_tasks_file(tests_by_task, gen_config, repeat_config,
-                                                       evg_api)
-
-        self.assertEqual(config, evg_config.to_map.return_value)
-
+    @unittest.skipIf(sys.platform.startswith("win"), "not supported on windows")
+    @patch(ns("sys.exit"))
     @patch(ns("create_generate_tasks_config"))
-    def test_gen_tasks_multiversion_configuration_is_returned(self, gen_tasks_config_mock):  # pylint: disable=invalid-name
-        evg_api = MagicMock()
-        gen_config = MagicMock(run_build_variant="variant", project="project",
-                               build_variant="build_variant", task_id="task_id",
-                               use_multiversion=True)
-        repeat_config = MagicMock()
-        tests_by_task = MagicMock()
-
-        evg_config = MagicMock()
-        evg_config.to_map.return_value = {
-            'buildvariants': [
-                {
-                    'name': 'build_variant',
-                    'display_tasks': [
-                        {
-                            'name': 'burn_in_tests_multiversion',
-                            'execution_tasks': [
-                                'burn_in_tests_multiversion_gen'
-                            ]
-                        }
-                    ]
-                }
-            ]
-        }  # yapf: disable
-
-        gen_tasks_config_mock.return_value = evg_config
-
-        config = under_test.create_generate_tasks_file(tests_by_task, gen_config, repeat_config,
-                                                       evg_api)
-        self.assertEqual(config, evg_config.to_map.return_value)
-
-    @patch("buildscripts.burn_in_tests.sys.exit")
-    @patch("buildscripts.burn_in_tests.create_generate_tasks_config")
-    def test_cap_on_task_generate(self, gen_tasks_config_mock, exit_mock):
+    @patch(ns("validate_task_generation_limit"))
+    def test_cap_on_task_generate(self, validate_mock, _, exit_mock):
         evg_api = MagicMock()
         gen_config = MagicMock(use_multiversion=False)
         repeat_config = MagicMock()
         tests_by_task = MagicMock()
 
-        task_list = [f"task_{i}" for i in range(1005)]
-
-        evg_config = MagicMock()
-        evg_config.to_map.return_value = {
-            "tasks": task_list,
-        }
-
-        gen_tasks_config_mock.return_value = evg_config
+        validate_mock.return_value = False
 
         exit_mock.side_effect = ValueError("exiting")
         with self.assertRaises(ValueError):
@@ -713,7 +634,7 @@ def create_variant_task_mock(task_name, suite_name, distro="distro"):
     variant_task.generated_task_name = task_name
     variant_task.resmoke_suite = suite_name
     variant_task.get_vars_suite_name.return_value = suite_name
-    variant_task.resmoke_args = f"--suites={suite_name}"
+    variant_task.combined_resmoke_args = f"--suites={suite_name}"
     variant_task.multiversion_path = None
     variant_task.run_on = [distro]
     return variant_task
@@ -742,29 +663,6 @@ class TestGatherTaskInfo(unittest.TestCase):
         self.assertIsNone(task_info["use_multiversion"])
         self.assertEqual(distro_name, task_info["distro"])
 
-    def test_multiversion_task(self):
-        suite_name = "suite_1"
-        distro_name = "distro_1"
-        variant = "build_variant"
-        evg_conf_mock = MagicMock()
-        evg_conf_mock.get_task.return_value.is_generate_resmoke_task = False
-        task_mock = create_variant_task_mock("task 1", suite_name, distro_name)
-        task_mock.multiversion_path = "/path/to/multiversion"
-        test_list = [f"test{i}.js" for i in range(3)]
-        tests_by_suite = {
-            suite_name: test_list,
-            "suite 2": [f"test{i}.js" for i in range(1)],
-            "suite 3": [f"test{i}.js" for i in range(2)],
-        }
-
-        task_info = under_test._gather_task_info(task_mock, tests_by_suite, evg_conf_mock, variant)
-
-        self.assertIn(suite_name, task_info["resmoke_args"])
-        for test in test_list:
-            self.assertIn(test, task_info["tests"])
-        self.assertEqual(task_mock.multiversion_path, task_info["use_multiversion"])
-        self.assertEqual(distro_name, task_info["distro"])
-
     def test_generated_task_no_large_on_task(self):
         suite_name = "suite_1"
         distro_name = "distro_1"
@@ -934,14 +832,7 @@ class TestCreateTaskList(unittest.TestCase):
 
 
 class TestFindChangedTests(unittest.TestCase):
-    @patch(ns("find_changed_files"))
-    def test_nothing_found(self, changed_files_mock):
-        repo_mock = MagicMock()
-        changed_files_mock.return_value = set()
-
-        self.assertEqual(0, len(under_test.find_changed_tests(repo_mock)))
-
-    @patch(ns("find_changed_files"))
+    @patch(ns("find_changed_files_in_repos"))
     @patch(ns("os.path.isfile"))
     def test_non_js_files_filtered(self, is_file_mock, changed_files_mock):
         repo_mock = MagicMock()
@@ -953,13 +844,13 @@ class TestFindChangedTests(unittest.TestCase):
         changed_files_mock.return_value = set(file_list)
         is_file_mock.return_value = True
 
-        found_tests = under_test.find_changed_tests(repo_mock)
+        found_tests = under_test.find_changed_tests([repo_mock])
 
         self.assertIn(file_list[0], found_tests)
         self.assertIn(file_list[2], found_tests)
         self.assertNotIn(file_list[1], found_tests)
 
-    @patch(ns("find_changed_files"))
+    @patch(ns("find_changed_files_in_repos"))
     @patch(ns("os.path.isfile"))
     def test_missing_files_filtered(self, is_file_mock, changed_files_mock):
         repo_mock = MagicMock()
@@ -971,11 +862,11 @@ class TestFindChangedTests(unittest.TestCase):
         changed_files_mock.return_value = set(file_list)
         is_file_mock.return_value = False
 
-        found_tests = under_test.find_changed_tests(repo_mock)
+        found_tests = under_test.find_changed_tests([repo_mock])
 
         self.assertEqual(0, len(found_tests))
 
-    @patch(ns("find_changed_files"))
+    @patch(ns("find_changed_files_in_repos"))
     @patch(ns("os.path.isfile"))
     def test_non_jstests_files_filtered(self, is_file_mock, changed_files_mock):
         repo_mock = MagicMock()
@@ -987,7 +878,7 @@ class TestFindChangedTests(unittest.TestCase):
         changed_files_mock.return_value = set(file_list)
         is_file_mock.return_value = True
 
-        found_tests = under_test.find_changed_tests(repo_mock)
+        found_tests = under_test.find_changed_tests([repo_mock])
 
         self.assertIn(file_list[0], found_tests)
         self.assertIn(file_list[2], found_tests)
