@@ -17,23 +17,18 @@ const ENABLE_FAULTS = "enable_faults";
 
 class FreeMonWebServer {
     /**
-    * Create a new webserver.
-    *
-    * @param {string} fault_type
-    * @param {bool} disableFaultsOnStartup optionally disable fault on startup
-    */
+     * Create a new webserver.
+     *
+     * @param {string} fault_type
+     * @param {bool} disableFaultsOnStartup optionally disable fault on startup
+     */
     constructor(fault_type, disableFaultsOnStartup) {
-        this.python = "/opt/mongodbtoolchain/v2/bin/python3";
+        this.python = "python3";
         this.disableFaultsOnStartup = disableFaultsOnStartup || false;
         this.fault_type = fault_type;
 
         if (_isWindows()) {
-            const paths = ["c:\\python36\\python.exe", "c:\\python\\python36\\python.exe"];
-            for (let p of paths) {
-                if (fileExists(p)) {
-                    this.python = p;
-                }
-            }
+            this.python = "python.exe";
         }
 
         print("Using python interpreter: " + this.python);
@@ -309,8 +304,8 @@ function WaitForFreeMonServerStatusState(conn, state) {
             let status = FreeMonGetServerStatus(conn).state;
             return status === state;
         },
-        "Failed to find expected server status state: expected: '" + state + "', actual: " +
-            tojson(FreeMonGetServerStatus(conn)),
+        "Failed to find expected server status state: expected: '" + state +
+            "', actual: " + tojson(FreeMonGetServerStatus(conn)),
         20 * 1000);
 }
 
