@@ -1,6 +1,8 @@
 /**
  * Test that oplog (on both primary and secondary) rolls over when its size exceeds the configured
  * maximum. This test runs on wiredTiger storage engine and inMemory storage engine (if available).
+ *
+ * @tags: [multiversion_incompatible]
  */
 (function() {
 "use strict";
@@ -33,8 +35,8 @@ function doTest(storageEngine) {
     const secondaryOplog = secondary.getDB("local").oplog.rs;
 
     // Verify that the oplog cap maintainer thread is paused.
-    checkLog.contains(primary, "Hanging the oplog cap maintainer thread due to fail point");
-    checkLog.contains(secondary, "Hanging the oplog cap maintainer thread due to fail point");
+    checkLog.containsJson(primary, 5095500);
+    checkLog.containsJson(secondary, 5095500);
 
     const coll = primary.getDB("test").foo;
     // 400KB each so that oplog can keep at most two insert oplog entries.
@@ -104,9 +106,9 @@ function doTest(storageEngine) {
         awaitCheckpointer(secondInsertTimestamp);
 
         // Insert the third document which will trigger a new oplog stone to be created. The
-        // oplog truncater thread will then be unblocked on the creation of the new oplog stone
-        // and will start truncating oplog entries. The oplog entry for the first insert will be
-        // truncated after the oplog truncater thread finishes.
+        // oplog cap maintainer thread will then be unblocked on the creation of the new oplog
+        // stone and will start truncating oplog entries. The oplog entry for the first
+        // insert will be truncated after the oplog cap maintainer thread finishes.
         const thirdInsertTimestamp =
             assert
                 .commandWorked(coll.runCommand(
@@ -133,7 +135,7 @@ function doTest(storageEngine) {
             {configureFailPoint: "hangOplogCapMaintainerThread", mode: "off"}));
 
         // Test that oplog entry of the initial insert rolls over on both primary and secondary.
-        // Use assert.soon to wait for oplog truncater thread to run.
+        // Use assert.soon to wait for oplog cap maintainer thread to run.
         assert.soon(() => {
             return numInsertOplogEntry(primaryOplog) === 2;
         }, "Timeout waiting for oplog to roll over on primary");
@@ -141,13 +143,10 @@ function doTest(storageEngine) {
             return numInsertOplogEntry(secondaryOplog) === 2;
         }, "Timeout waiting for oplog to roll over on secondary");
 
-        if (jsTest.options().storageEngine == "wiredTiger") {
-            const res = primary.getDB("test").runCommand({serverStatus: 1});
-            assert.commandWorked(res);
-            assert.eq(res.oplogTruncation.truncateCount, 1, tojson(res.oplogTruncation));
-            assert.gt(
-                res.oplogTruncation.totalTimeTruncatingMicros, 0, tojson(res.oplogTruncation));
-        }
+        const res = primary.getDB("test").runCommand({serverStatus: 1});
+        assert.commandWorked(res);
+        assert.eq(res.oplogTruncation.truncateCount, 1, tojson(res.oplogTruncation));
+        assert.gt(res.oplogTruncation.totalTimeTruncatingMicros, 0, tojson(res.oplogTruncation));
     } else {
         // Let the oplog cap maintainer thread start truncating the oplog.
         assert.commandWorked(primary.adminCommand(
