@@ -98,6 +98,7 @@ let testCases = {
     _configsvrRemoveShard: {skip: "internal command"},
     _configsvrRemoveShardFromZone: {skip: "internal command"},
     _configsvrRenameCollection: {skip: "internal command"},
+    _configsvrRepairShardedCollectionChunksHistory: {skip: "internal command"},
     _configsvrShardCollection: {skip: "internal command"},
     _configsvrUpdateZoneKeyRange: {skip: "internal command"},
     _flushDatabaseCacheUpdates: {skip: "internal command"},
@@ -522,6 +523,7 @@ let testCases = {
         checkWriteConcern: true,
     },
     repairDatabase: {skip: "does not accept read or write concern"},
+    repairShardedCollectionChunksHistory: {skip: "does not accept read or write concern"},
     replSetAbortPrimaryCatchUp: {skip: "does not accept read or write concern"},
     replSetFreeze: {skip: "does not accept read or write concern"},
     replSetGetConfig: {skip: "does not accept read or write concern"},
