@@ -12,6 +12,7 @@ import (
 	"strings"
 
 	"github.com/mongodb/mongo-tools/common/db"
+	"github.com/mongodb/mongo-tools/common/idx"
 	"github.com/mongodb/mongo-tools/common/intents"
 	"github.com/mongodb/mongo-tools/common/log"
 	"github.com/mongodb/mongo-tools/common/util"
@@ -36,17 +37,10 @@ type authVersionPair struct {
 
 // Metadata holds information about a collection's options and indexes.
 type Metadata struct {
-	Options        bson.D          `bson:"options,omitempty"`
-	Indexes        []IndexDocument `bson:"indexes"`
-	UUID           string          `bson:"uuid"`
-	CollectionName string          `bson:"collectionName"`
-}
-
-// IndexDocument holds information about a collection's index.
-type IndexDocument struct {
-	Options                 bson.M `bson:",inline"`
-	Key                     bson.D `bson:"key"`
-	PartialFilterExpression bson.D `bson:"partialFilterExpression,omitempty"`
+	Options        bson.D               `bson:"options,omitempty"`
+	Indexes        []*idx.IndexDocument `bson:"indexes"`
+	UUID           string               `bson:"uuid"`
+	CollectionName string               `bson:"collectionName"`
 }
 
 // MetadataFromJSON takes a slice of JSON bytes and unmarshals them into usable
@@ -86,7 +80,7 @@ func (restore *MongoRestore) LoadIndexesFromBSON() error {
 
 		// iterate over stored indexes, saving all that match the collection
 		for {
-			indexDocument := IndexDocument{}
+			indexDocument := &idx.IndexDocument{}
 			if !bsonSource.Next(&indexDocument) {
 				break
 			}
@@ -108,7 +102,7 @@ func stripDBFromNS(ns string) string {
 }
 
 // CollectionExists returns true if the given intent's collection exists.
-func (restore *MongoRestore) CollectionExists(intent *intents.Intent) (bool, error) {
+func (restore *MongoRestore) CollectionExists(dbName, coll string) (bool, error) {
 	restore.knownCollectionsMutex.Lock()
 	defer restore.knownCollectionsMutex.Unlock()
 
@@ -118,14 +112,14 @@ func (restore *MongoRestore) CollectionExists(intent *intents.Intent) (bool, err
 	}
 
 	// first check if we haven't done listCollections for this database already
-	if restore.knownCollections[intent.DB] == nil {
+	if restore.knownCollections[dbName] == nil {
 		// if the database name isn't in the cache, grab collection
 		// names from the server
 		session, err := restore.SessionProvider.GetSession()
 		if err != nil {
 			return false, fmt.Errorf("error establishing connection: %v", err)
 		}
-		collections, err := session.Database(intent.DB).ListCollections(nil, bson.M{})
+		collections, err := session.Database(dbName).ListCollections(nil, bson.M{})
 		if err != nil {
 			return false, err
 		}
@@ -136,12 +130,12 @@ func (restore *MongoRestore) CollectionExists(intent *intents.Intent) (bool, err
 			if !ok {
 				return false, fmt.Errorf("invalid collection name: %v", colNameRaw)
 			}
-			restore.knownCollections[intent.DB] = append(restore.knownCollections[intent.DB], colName)
+			restore.knownCollections[dbName] = append(restore.knownCollections[dbName], colName)
 		}
 	}
 
 	// now check the cache for the given collection name
-	exists := util.StringSliceContains(restore.knownCollections[intent.DB], intent.C)
+	exists := util.StringSliceContains(restore.knownCollections[dbName], coll)
 	return exists, nil
 }
 
@@ -157,7 +151,7 @@ func (restore *MongoRestore) addToKnownCollections(intent *intents.Intent) {
 // CreateIndexes takes in an intent and an array of index documents and
 // attempts to create them using the createIndexes command. If that command
 // fails, we fall back to individual index creation.
-func (restore *MongoRestore) CreateIndexes(dbName string, collectionName string, indexes []IndexDocument, hasNonSimpleCollation bool) error {
+func (restore *MongoRestore) CreateIndexes(dbName string, collectionName string, indexes []*idx.IndexDocument) error {
 	// first, sanitize the indexes
 	var indexNames []string
 	for _, index := range indexes {
@@ -180,12 +174,6 @@ func (restore *MongoRestore) CreateIndexes(dbName string, collectionName string,
 		if !restore.OutputOptions.KeepIndexVersion {
 			delete(index.Options, "v")
 		}
-
-		// for non-simple default collation on the collection, indexes without
-		// a collation option need to add "collation:{locale:"simple"}}
-		if _, ok := index.Options["collation"]; hasNonSimpleCollation && !ok {
-			index.Options["collation"] = bson.D{{"locale", "simple"}}
-		}
 	}
 
 	session, err := restore.SessionProvider.GetSession()
@@ -227,7 +215,7 @@ func (restore *MongoRestore) CreateIndexes(dbName string, collectionName string,
 
 // LegacyInsertIndex takes in an intent and an index document and attempts to
 // create the index on the "system.indexes" collection.
-func (restore *MongoRestore) LegacyInsertIndex(dbName string, index IndexDocument) error {
+func (restore *MongoRestore) LegacyInsertIndex(dbName string, index *idx.IndexDocument) error {
 	session, err := restore.SessionProvider.GetSession()
 	if err != nil {
 		return fmt.Errorf("error establishing connection: %v", err)
@@ -409,7 +397,7 @@ func (restore *MongoRestore) RestoreUsersOrRoles(users, roles *intents.Intent) e
 		bsonSource := db.NewDecodedBSONSource(db.NewBSONSource(arg.intent.BSONFile))
 		defer bsonSource.Close()
 
-		tempCollectionNameExists, err := restore.CollectionExists(&intents.Intent{DB: "admin", C: arg.tempCollectionName})
+		tempCollectionNameExists, err := restore.CollectionExists("admin", arg.tempCollectionName)
 		if err != nil {
 			return err
 		}
@@ -422,7 +410,7 @@ func (restore *MongoRestore) RestoreUsersOrRoles(users, roles *intents.Intent) e
 		}
 
 		log.Logvf(log.DebugLow, "restoring %v to temporary collection", arg.intentType)
-		result := restore.RestoreCollectionToDB("admin", arg.tempCollectionName, bsonSource, arg.intent.BSONFile, 0)
+		result := restore.RestoreCollectionToDB("admin", arg.tempCollectionName, bsonSource, arg.intent.BSONFile, 0, "")
 		if result.Err != nil {
 			return fmt.Errorf("error restoring %v: %v", arg.intentType, result.Err)
 		}
