@@ -29,10 +29,12 @@
 
 #pragma once
 
+#include <functional>
 #include <map>
 #include <set>
 
 #include "mongo/db/catalog/collection.h"
+#include "mongo/db/profile_filter.h"
 #include "mongo/db/service_context.h"
 #include "mongo/stdx/unordered_map.h"
 #include "mongo/util/uuid.h"
@@ -62,7 +64,7 @@ public:
         iterator(StringData dbName, uint64_t genNum, const CollectionCatalog& catalog);
         iterator(
             std::map<std::pair<std::string, CollectionUUID>, Collection*>::const_iterator mapIter);
-        const value_type operator*();
+        value_type operator*();
         iterator operator++();
         iterator operator++(int);
         boost::optional<CollectionUUID> uuid();
@@ -94,6 +96,26 @@ public:
         static constexpr Collection* _nullCollection = nullptr;
     };
 
+    struct ProfileSettings {
+        int level;
+        std::shared_ptr<ProfileFilter> filter;  // nullable
+
+        ProfileSettings(int level, std::shared_ptr<ProfileFilter> filter)
+            : level(level), filter(filter) {
+            // ProfileSettings represents a state, not a request to change the state.
+            // -1 is not a valid profiling level: it is only used in requests, to represent
+            // leaving the state unchanged.
+            invariant(0 <= level && level <= 2,
+                      str::stream() << "Invalid profiling level: " << level);
+        }
+
+        ProfileSettings() = default;
+
+        bool operator==(const ProfileSettings& other) {
+            return level == other.level && filter == other.filter;
+        }
+    };
+
     static CollectionCatalog& get(ServiceContext* svcCtx);
     static CollectionCatalog& get(OperationContext* opCtx);
     CollectionCatalog() = default;
@@ -115,7 +137,7 @@ public:
     /**
      * Register the collection with `uuid`.
      */
-    void registerCollection(CollectionUUID uuid, std::unique_ptr<Collection> collection);
+    void registerCollection(CollectionUUID uuid, std::unique_ptr<Collection>* collection);
 
     /**
      * Deregister the collection.
@@ -125,8 +147,8 @@ public:
     /**
      * Returns the RecoveryUnit's Change for dropping the collection
      */
-    RecoveryUnit::Change* makeFinishDropCollectionChange(std::unique_ptr<Collection>,
-                                                         CollectionUUID uuid);
+    std::unique_ptr<RecoveryUnit::Change> makeFinishDropCollectionChange(
+        std::unique_ptr<Collection>, CollectionUUID uuid);
 
     /**
      * Deregister all the collection objects.
@@ -140,7 +162,7 @@ public:
      *
      * Returns nullptr if the 'uuid' is not known.
      */
-    Collection* lookupCollectionByUUID(CollectionUUID uuid) const;
+    Collection* lookupCollectionByUUID(OperationContext* opCtx, CollectionUUID uuid) const;
 
     /**
      * Like lookupCollectionByUUID but also verifies the namespace under the catalog lock. Used when
@@ -150,7 +172,17 @@ public:
      * namespace check, none otherwise.
      */
     std::pair<Collection*, boost::optional<NamespaceString>>
-    lookupCollectionByUUIDAndVerifyNamespace(CollectionUUID uuid, const NamespaceString& nss) const;
+    lookupCollectionByUUIDAndVerifyNamespace(OperationContext* opCtx,
+                                             CollectionUUID uuid,
+                                             const NamespaceString& nss) const;
+
+    void makeCollectionVisible(CollectionUUID uuid);
+
+    /**
+     * Returns true if the collection has been registered in the CollectionCatalog but not yet made
+     * visible.
+     */
+    bool isCollectionAwaitingVisibility(CollectionUUID uuid) const;
 
     /**
      * This function gets the Collection pointer that corresponds to the NamespaceString.
@@ -159,20 +191,30 @@ public:
      *
      * Returns nullptr if the namespace is unknown.
      */
-    Collection* lookupCollectionByNamespace(const NamespaceString& nss) const;
+    Collection* lookupCollectionByNamespace(OperationContext* opCtx,
+                                            const NamespaceString& nss) const;
 
     /**
      * This function gets the NamespaceString from the collection catalog entry that
      * corresponds to CollectionUUID uuid. If no collection exists with the uuid, return
      * boost::none. See onCloseCatalog/onOpenCatalog for more info.
      */
-    boost::optional<NamespaceString> lookupNSSByUUID(CollectionUUID uuid) const;
+    boost::optional<NamespaceString> lookupNSSByUUID(OperationContext* opCtx,
+                                                     CollectionUUID uuid) const;
 
     /**
-     * Returns the UUID if `nss` exists in CollectionCatalog. The time complexity of
-     * this function is linear to the number of collections in `nss.db()`.
+     * Returns the UUID if `nss` exists in CollectionCatalog.
      */
-    boost::optional<CollectionUUID> lookupUUIDByNSS(const NamespaceString& nss) const;
+    boost::optional<CollectionUUID> lookupUUIDByNSS(OperationContext* opCtx,
+                                                    const NamespaceString& nss) const;
+
+    /**
+     * Without acquiring any locks resolves the given NamespaceStringOrUUID to an actual namespace.
+     * Throws NamespaceNotFound if the collection UUID cannot be resolved to a name, or if the UUID
+     * can be resolved, but the resulting collection is in the wrong database.
+     */
+    NamespaceString resolveNamespaceStringOrUUID(OperationContext* opCtx,
+                                                 NamespaceStringOrUUID nsOrUUID);
 
     /**
      * Returns whether the collection with 'uuid' satisfies the provided 'predicate'. If the
@@ -204,9 +246,40 @@ public:
     /**
      * This functions gets all the database names. The result is sorted in alphabetical ascending
      * order.
+     *
+     * Unlike DatabaseHolder::getNames(), this does not return databases that are empty.
      */
     std::vector<std::string> getAllDbNames() const;
 
+    /**
+     * Sets 'newProfileSettings' as the profiling settings for the database 'dbName'.
+     */
+    void setDatabaseProfileSettings(StringData dbName, ProfileSettings newProfileSettings);
+
+    /**
+     * Fetches the profiling settings for database 'dbName'.
+     *
+     * Returns the server's default database profile settings if the database does not exist.
+     */
+    ProfileSettings getDatabaseProfileSettings(StringData dbName) const;
+
+    /**
+     * Fetches the profiling level for database 'dbName'.
+     *
+     * Returns the server's default database profile settings if the database does not exist.
+     *
+     * There is no corresponding setDatabaseProfileLevel; use setDatabaseProfileSettings instead.
+     * This method only exists as a convenience.
+     */
+    int getDatabaseProfileLevel(StringData dbName) const {
+        return getDatabaseProfileSettings(dbName).level;
+    }
+
+    /**
+     * Clears the database profile settings entry for 'dbName'.
+     */
+    void clearDatabaseProfileSettings(StringData dbName);
+
     /**
      * Puts the catalog in closed state. In this state, the lookupNSSByUUID method will fall back
      * to the pre-close state to resolve queries for currently unknown UUIDs. This allows processes,
@@ -261,10 +334,12 @@ private:
         mongo::stdx::unordered_map<CollectionUUID, NamespaceString, CollectionUUID::Hash>>
         _shadowCatalog;
 
-    using CollectionCatalogMap = mongo::stdx::
-        unordered_map<CollectionUUID, std::unique_ptr<Collection>, CollectionUUID::Hash>;
+    using CollectionCatalogMap =
+        stdx::unordered_map<CollectionUUID, std::unique_ptr<Collection>, CollectionUUID::Hash>;
     using OrderedCollectionMap = std::map<std::pair<std::string, CollectionUUID>, Collection*>;
-    using NamespaceCollectionMap = mongo::stdx::unordered_map<NamespaceString, Collection*>;
+    using NamespaceCollectionMap = stdx::unordered_map<NamespaceString, Collection*>;
+    using DatabaseProfileSettingsMap = StringMap<ProfileSettings>;
+
     CollectionCatalogMap _catalog;
     OrderedCollectionMap _orderedCollections;  // Ordered by <dbName, collUUID> pair
     NamespaceCollectionMap _collections;
@@ -279,5 +354,17 @@ private:
 
     // Mapping from ResourceId to a set of strings that contains collection and database namespaces.
     std::map<ResourceId, std::set<std::string>> _resourceInformation;
+
+    // Protects _databaseProfileSettings.
+    mutable Mutex _profileSettingsLock =
+        MONGO_MAKE_LATCH("CollectionCatalog::_profileSettingsLock");
+
+    /**
+     * Contains non-default database profile settings. New collections, current collections and
+     * views must all be able to access the correct profile settings for the database in which they
+     * reside. Simple database name to struct ProfileSettings map. Access protected by
+     * _profileSettingsLock.
+     */
+    DatabaseProfileSettingsMap _databaseProfileSettings;
 };
 }  // namespace mongo
