@@ -27,7 +27,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kNetwork
+#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kNetwork
 
 #include "mongo/platform/basic.h"
 
@@ -39,12 +39,12 @@
 #include "mongo/client/replica_set_monitor.h"
 #include "mongo/db/bson/dotted_path_support.h"
 #include "mongo/db/query/query_request.h"
+#include "mongo/logv2/log.h"
 #include "mongo/rpc/get_status_from_command_result.h"
 #include "mongo/s/catalog_cache.h"
 #include "mongo/s/client/shard_connection.h"
 #include "mongo/s/client/shard_registry.h"
 #include "mongo/s/grid.h"
-#include "mongo/util/log.h"
 #include "mongo/util/net/socket_exception.h"
 
 namespace mongo {
@@ -198,7 +198,7 @@ ParallelSortClusteredCursor::~ParallelSortClusteredCursor() {
     }
 
     delete[] _cursors;
-    _cursors = 0;
+    _cursors = nullptr;
 
     // Clear out our metadata after removing legacy cursor data
     _cursorMap.clear();
@@ -224,11 +224,11 @@ void ParallelSortClusteredCursor::init(OperationContext* opCtx) {
 void ParallelSortClusteredCursor::_finishCons() {
     _numServers = _servers.size();
     _lastFrom = 0;
-    _cursors = 0;
+    _cursors = nullptr;
 
     if (!_qSpec.isEmpty()) {
         _needToSkip = _qSpec.ntoskip();
-        _cursors = 0;
+        _cursors = nullptr;
         _sortKey = _qSpec.sort();
         _fields = _qSpec.fields();
     }
@@ -361,7 +361,7 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
     if (allowShardVersionFailure) {
         const DBClientReplicaSet* replConn = dynamic_cast<const DBClientReplicaSet*>(rawConn);
         invariant(replConn);
-        ReplicaSetMonitorPtr rsMonitor = ReplicaSetMonitor::get(replConn->getSetName());
+        auto rsMonitor = ReplicaSetMonitor::get(replConn->getSetName());
         uassert(16388,
                 str::stream() << "cannot access unknown replica set: " << replConn->getSetName(),
                 rsMonitor != nullptr);
@@ -376,9 +376,13 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
             if (sampler.tick()) {
                 const DBClientReplicaSet* repl = dynamic_cast<const DBClientReplicaSet*>(rawConn);
                 dassert(repl);
-                warning() << "Primary for " << repl->getServerAddress()
-                          << " was down before, bypassing setShardVersion."
-                          << " The local replica set view and targeting may be stale.";
+                LOGV2_WARNING(
+                    22695,
+                    "Primary for {replicaSetAddress} was down before, bypassing "
+                    "setShardVersion. The local replica set view and targeting may be stale.",
+                    "Bypassing setShardVersion because replica set view and targeting may be stale "
+                    "from primary having been down",
+                    "replicaSetAddress"_attr = repl->getServerAddress());
             }
 
             return;
@@ -387,8 +391,12 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
 
     try {
         if (state->conn->setVersion()) {
-            LOG(2) << "pcursor: needed to set remote version on connection to value "
-                   << "compatible with " << vinfo;
+            LOGV2_DEBUG(22678,
+                        2,
+                        "pcursor: needed to set remote version on connection to value compatible "
+                        "with {shardVersion}",
+                        "pcursor: needed to set remote version on connection",
+                        "shardVersion"_attr = vinfo);
         }
     } catch (const DBException& dbExcep) {
         auto errCode = dbExcep.code();
@@ -403,9 +411,13 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
                 const DBClientReplicaSet* repl =
                     dynamic_cast<const DBClientReplicaSet*>(state->conn->getRawConn());
                 dassert(repl);
-                warning() << "Cannot contact primary for " << repl->getServerAddress()
-                          << " to check shard version."
-                          << " The local replica set view and targeting may be stale.";
+                LOGV2_WARNING(
+                    22696,
+                    "Cannot contact replica set {replicaSetAdress} to check shard version. "
+                    "The local replica set view and targeting may be stale",
+                    "Cannot contact replica set to check shard version. "
+                    "The local replica set view and targeting may be stale",
+                    "replicaSetAddress"_attr = repl->getServerAddress());
             }
         } else {
             throw;
@@ -418,14 +430,20 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     const NamespaceString nss(!_cInfo.isEmpty() ? _cInfo.versionedNS : _qSpec.ns());
 
     string prefix;
-    if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
+    if (MONGO_unlikely(shouldLog(logv2::LogSeverity::Debug(2)))) {
         if (_totalTries > 0) {
             prefix = str::stream() << "retrying (" << _totalTries << " tries)";
         } else {
             prefix = "creating";
         }
     }
-    LOG(2) << "pcursor: " << prefix << " pcursor over " << _qSpec << " and " << _cInfo;
+    LOGV2_DEBUG(22679,
+                2,
+                "pcursor: {prefix} pcursor over {query} and {command}",
+                "pcursor",
+                "prefix"_attr = prefix,
+                "query"_attr = _qSpec,
+                "command"_attr = _cInfo);
 
     shared_ptr<ChunkManager> manager;
     shared_ptr<Shard> primary;
@@ -448,7 +466,7 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     string vinfo;
 
     if (manager) {
-        if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
+        if (MONGO_unlikely(shouldLog(logv2::LogSeverity::Debug(2)))) {
             vinfo = str::stream() << "[" << manager->getns().ns() << " @ "
                                   << manager->getVersion().toString() << "]";
         }
@@ -458,7 +476,7 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                                      !_cInfo.isEmpty() ? _cInfo.cmdCollation : BSONObj(),
                                      &shardIds);
     } else if (primary) {
-        if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
+        if (MONGO_unlikely(shouldLog(logv2::LogSeverity::Debug(2)))) {
             vinfo = str::stream() << "[unsharded @ " << primary->toString() << "]";
         }
 
@@ -470,14 +488,24 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
         const auto& shardId = cmEntry.first;
 
         if (shardIds.find(shardId) == shardIds.end()) {
-            LOG(2) << "pcursor: closing cursor on shard " << shardId
-                   << " as the connection is no longer required by " << vinfo;
+            LOGV2_DEBUG(22680,
+                        2,
+                        "pcursor: closing cursor on shard {shardId} as the connection is no longer "
+                        "required by {shardVersion}",
+                        "pcursor: closing cursor as the connection is no longer required",
+                        "shardId"_attr = shardId,
+                        "shardVersion"_attr = vinfo);
 
             cmEntry.second.cleanup(true);
         }
     }
 
-    LOG(2) << "pcursor: initializing over " << shardIds.size() << " shards required by " << vinfo;
+    LOGV2_DEBUG(22681,
+                2,
+                "pcursor: initializing over {shardsNumber} shards required by {shardVersion}",
+                "pcursor: initializing for all shards",
+                "shardsNumber"_attr = shardIds.size(),
+                "shardVersion"_attr = vinfo);
 
     // Don't retry indefinitely for whatever reason
     _totalTries++;
@@ -486,8 +514,13 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     for (const ShardId& shardId : shardIds) {
         auto& mdata = _cursorMap[shardId];
 
-        LOG(2) << "pcursor: initializing on shard " << shardId << ", current connection state is "
-               << mdata.toBSON();
+        LOGV2_DEBUG(22682,
+                    2,
+                    "pcursor: initializing on shard {shardId}, current connection state is "
+                    "{connectionState}",
+                    "pcursor: initializing on shard",
+                    "shardId"_attr = shardId,
+                    "connectionState"_attr = mdata.toBSON());
 
         // This may be the first time connecting to this shard, if so we can get an error here
         try {
@@ -500,11 +533,11 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                 bool compatibleManager = true;
 
                 if (primary && !state->primary)
-                    warning() << "Collection becoming unsharded detected";
+                    LOGV2_WARNING(22697, "Collection becoming unsharded detected");
                 if (manager && !state->manager)
-                    warning() << "Collection becoming sharded detected";
+                    LOGV2_WARNING(22698, "Collection becoming sharded detected");
                 if (primary && state->primary && primary != state->primary)
-                    warning() << "Weird shift of primary detected";
+                    LOGV2_WARNING(22699, "Weird shift of primary detected");
 
                 compatiblePrimary = primary && state->primary && primary == state->primary;
                 compatibleManager =
@@ -552,8 +585,9 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                         isCommand() ? 1 : 0,  // nToReturn (0 if query indicates multi)
                         0,                    // nToSkip
                         // Does this need to be a ptr?
-                        _qSpec.fields().isEmpty() ? 0 : _qSpec.fieldsData(),  // fieldsToReturn
-                        _qSpec.options(),                                     // options
+                        _qSpec.fields().isEmpty() ? nullptr
+                                                  : _qSpec.fieldsData(),  // fieldsToReturn
+                        _qSpec.options(),                                 // options
                         // NtoReturn is weird.
                         // If zero, it means use default size, so we do that for all cursors
                         // If positive, it's the batch size (we don't want this cursor limiting
@@ -580,9 +614,10 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                         _qSpec.ntoreturn(),  // nToReturn
                         _qSpec.ntoskip(),    // nToSkip
                         // Does this need to be a ptr?
-                        _qSpec.fields().isEmpty() ? 0 : _qSpec.fieldsData(),  // fieldsToReturn
-                        _qSpec.options(),                                     // options
-                        0));                                                  // batchSize
+                        _qSpec.fields().isEmpty() ? nullptr
+                                                  : _qSpec.fieldsData(),  // fieldsToReturn
+                        _qSpec.options(),                                 // options
+                        0));                                              // batchSize
                 }
             }
 
@@ -607,32 +642,55 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                 mdata.finished = true;
             }
 
-            LOG(2) << "pcursor: initialized " << (isCommand() ? "command " : "query ")
-                   << (lazyInit ? "(lazily) " : "(full) ") << "on shard " << shardId
-                   << ", current connection state is " << mdata.toBSON();
+            LOGV2_DEBUG(22683,
+                        2,
+                        "pcursor: initialized {commandType} ({lazyInit}) on shard {shardId}, "
+                        "current connection state is {connectionState}",
+                        "pcursor: initialized command",
+                        "commandType"_attr = (isCommand() ? "command" : "query"),
+                        "lazyInit"_attr = (lazyInit ? "lazily" : "full"),
+                        "shardId"_attr = shardId,
+                        "connectionState"_attr = mdata.toBSON());
         } catch (StaleConfigException& e) {
             // Our version isn't compatible with the current version anymore on at least one shard,
             // need to retry immediately
             NamespaceString staleNS(e->getNss());
             _markStaleNS(staleNS, e);
 
-            Grid::get(opCtx)->catalogCache()->invalidateShardedCollection(staleNS);
+            Grid::get(opCtx)
+                ->catalogCache()
+                ->invalidateShardOrEntireCollectionEntryForShardedCollection(
+                    opCtx, nss, e->getVersionWanted(), e->getVersionReceived(), e->getShardId());
 
-            LOG(1) << "stale config of ns " << staleNS << " during initialization, will retry"
-                   << causedBy(redact(e));
+            LOGV2_DEBUG(22684,
+                        1,
+                        "Error initializing pcursor, stale config for namespace {namespace}, "
+                        "caused by {error}, will retry",
+                        "Error initializing pcursor, will retry",
+                        "namespace"_attr = staleNS,
+                        "error"_attr = redact(e));
 
             // This is somewhat strange
             if (staleNS != nss) {
-                warning() << "versioned ns " << nss.ns() << " doesn't match stale config namespace "
-                          << staleNS;
+                LOGV2_WARNING(22700,
+                              "Versioned namespace {namespace} doesn't match stale config "
+                              "namespace {staleNamespace}",
+                              "Versioned namespace doesn't match stale config namespace",
+                              "namespace"_attr = nss.ns(),
+                              "staleNamespace"_attr = staleNS);
             }
 
             // Restart with new chunk manager
             startInit(opCtx);
             return;
         } catch (NetworkException& e) {
-            warning() << "socket exception when initializing on " << shardId
-                      << ", current connection state is " << mdata.toBSON() << causedBy(redact(e));
+            LOGV2_WARNING(22701,
+                          "Error initializing pcursor on {shardId} with current connection state "
+                          "{connectionState} caused by {error}",
+                          "Error initializing pcursor",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = redact(e));
             mdata.errored = true;
             if (returnPartial) {
                 mdata.cleanup(true);
@@ -640,8 +698,13 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
             }
             throw;
         } catch (DBException& e) {
-            warning() << "db exception when initializing on " << shardId
-                      << ", current connection state is " << mdata.toBSON() << causedBy(redact(e));
+            LOGV2_WARNING(22702,
+                          "Error initializing pcursor on {shardId} with current connection state "
+                          "{connectionState} caused by {error}",
+                          "Error initializing pcursor",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = redact(e));
             mdata.errored = true;
             if (returnPartial && e.code() == 15925 /* From above! */) {
                 mdata.cleanup(true);
@@ -649,13 +712,23 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
             }
             throw;
         } catch (std::exception& e) {
-            warning() << "exception when initializing on " << shardId
-                      << ", current connection state is " << mdata.toBSON() << causedBy(e);
+            LOGV2_WARNING(22703,
+                          "Error initializing pcursor on {shardId} with current connection state "
+                          "{connectionState} caused by {error}",
+                          "Error initializing pcursor",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = redact(e.what()));
             mdata.errored = true;
             throw;
         } catch (...) {
-            warning() << "unknown exception when initializing on " << shardId
-                      << ", current connection state is " << mdata.toBSON();
+            LOGV2_WARNING(22704,
+                          "Error initializing pcursor on {shardId} with current connection state "
+                          "{connectionState} caused by {error}",
+                          "Error initializing pcursor",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = "uknownError");
             mdata.errored = true;
             throw;
         }
@@ -704,14 +777,23 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
     bool retry = false;
     map<string, StaleConfigException> staleNSExceptions;
 
-    LOG(2) << "pcursor: finishing over " << _cursorMap.size() << " shards";
+    LOGV2_DEBUG(22685,
+                2,
+                "pcursor: finishing over {shardsCount} shards",
+                "pcursor: finishing initialization",
+                "shardsCount"_attr = _cursorMap.size());
 
     for (auto& cmEntry : _cursorMap) {
         const auto& shardId = cmEntry.first;
         auto& mdata = cmEntry.second;
 
-        LOG(2) << "pcursor: finishing on shard " << shardId << ", current connection state is "
-               << mdata.toBSON();
+        LOGV2_DEBUG(22686,
+                    2,
+                    "pcursor: finishing initialization on shard {shardId}, current connection "
+                    "state is {connectionState}",
+                    "pcursor: finishing initialization for shard",
+                    "shardId"_attr = shardId,
+                    "connectionState"_attr = mdata.toBSON());
 
         // Ignore empty conns for now
         if (!mdata.pcState)
@@ -758,8 +840,13 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
                 // Finalize state
                 state->cursor->attach(state->conn.get());  // Closes connection for us
 
-                LOG(2) << "pcursor: finished on shard " << shardId
-                       << ", current connection state is " << mdata.toBSON();
+                LOGV2_DEBUG(22687,
+                            2,
+                            "pcursor: finished on shard {shardId}, current connection state is "
+                            "{connectionState}",
+                            "pcursor: finished initialization for shard",
+                            "shardId"_attr = shardId,
+                            "connectionState"_attr = mdata.toBSON());
             }
         } catch (StaleConfigException& e) {
             retry = true;
@@ -773,8 +860,13 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
             mdata.cleanup(true);
             continue;
         } catch (NetworkException& e) {
-            warning() << "socket exception when finishing on " << shardId
-                      << ", current connection state is " << mdata.toBSON() << causedBy(redact(e));
+            LOGV2_WARNING(22705,
+                          "Error finalizing pcursor initialization for shard {shardId} with "
+                          "connection state {connectionState} caused by {error}",
+                          "Error finalizing pcursor initialization for shard",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = redact(e));
             mdata.errored = true;
             if (returnPartial) {
                 mdata.cleanup(true);
@@ -785,9 +877,13 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
             // NOTE: RECV() WILL NOT THROW A SOCKET EXCEPTION - WE GET THIS AS ERROR 15988 FROM
             // ABOVE
             if (e.code() == 15988) {
-                warning() << "exception when receiving data from " << shardId
-                          << ", current connection state is " << mdata.toBSON()
-                          << causedBy(redact(e));
+                LOGV2_WARNING(22706,
+                              "Error finalizing pcursor initialization for shard {shardId} with "
+                              "connection state {connectionState} caused by {error}",
+                              "Error finalizing pcursor initialization for shard",
+                              "shardId"_attr = shardId,
+                              "connectionState"_attr = mdata.toBSON(),
+                              "error"_attr = redact(e));
 
                 mdata.errored = true;
                 if (returnPartial) {
@@ -799,23 +895,42 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
                 // the InvalidBSON exception indicates that the BSON is malformed ->
                 // don't print/call "mdata.toBSON()" to avoid unexpected errors e.g. a segfault
                 if (e.code() == ErrorCodes::InvalidBSON)
-                    warning() << "bson is malformed :: db exception when finishing on " << shardId
-                              << causedBy(redact(e));
+                    LOGV2_WARNING(22707,
+                                  "Error finalizing pcursor initialization for shard "
+                                  "{shardId} caused by {error}",
+                                  "Error finalizing pcursor initialization for shard",
+                                  "shardId"_attr = shardId,
+                                  "error"_attr = redact(e));
                 else
-                    warning() << "db exception when finishing on " << shardId
-                              << ", current connection state is " << mdata.toBSON()
-                              << causedBy(redact(e));
+                    LOGV2_WARNING(
+                        22708,
+                        "Error finalizing pcursor initialization for shard {shardId} with "
+                        "connection state {connectionState} caused by {error}",
+                        "Error finalizing pcursor initialization for shard",
+                        "shardId"_attr = shardId,
+                        "connectionState"_attr = mdata.toBSON(),
+                        "error"_attr = redact(e));
                 mdata.errored = true;
                 throw;
             }
         } catch (std::exception& e) {
-            warning() << "exception when finishing on " << shardId
-                      << ", current connection state is " << mdata.toBSON() << causedBy(e);
+            LOGV2_WARNING(22709,
+                          "Error finalizing pcursor initialization for shard {shardId} with "
+                          "connection state {connectionState} caused by {error}",
+                          "Error finalizing pcursor initialization for shard",
+                          "shardId"_attr = shardId,
+                          "connectionState"_attr = mdata.toBSON(),
+                          "error"_attr = redact(e.what()));
             mdata.errored = true;
             throw;
         } catch (...) {
-            warning() << "unknown exception when finishing on " << shardId
-                      << ", current connection state is " << mdata.toBSON();
+            LOGV2_WARNING(
+                22710,
+                "Unknown error finalizing pcursor initialization for shard {shardId} with "
+                "connection state {connectionState}",
+                "Unknown error finalizing pcursor initialization for shard",
+                "shardId"_attr = shardId,
+                "connectionState"_attr = mdata.toBSON());
             mdata.errored = true;
             throw;
         }
@@ -830,15 +945,31 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
                 const StaleConfigException& ex = exEntry.second;
 
                 _markStaleNS(staleNS, ex);
-                Grid::get(opCtx)->catalogCache()->invalidateShardedCollection(staleNS);
+                // If we don't have a shardId (a valid case being receiving an exception from a
+                // v4.2 binary), we have to set the entire collection as stale.
+                if (!ex->getShardId()) {
+                    Grid::get(opCtx)->catalogCache()->onEpochChange(staleNS);
+                } else {
+                    Grid::get(opCtx)->catalogCache()->invalidateShardForShardedCollection(
+                        staleNS, *ex->getShardId());
+                }
 
-                LOG(1) << "stale config of ns " << staleNS << " on finishing query, will retry"
-                       << causedBy(redact(ex));
+                LOGV2_DEBUG(22688,
+                            1,
+                            "Found stale config for namespace {namespace} on finishing query "
+                            "caused by {error}",
+                            "Found stale config for namespace",
+                            "namespace"_attr = staleNS,
+                            "error"_attr = redact(ex));
 
                 // This is somewhat strange
                 if (staleNS.ns() != ns) {
-                    warning() << "versioned ns " << ns << " doesn't match stale config namespace "
-                              << staleNS;
+                    LOGV2_WARNING(22711,
+                                  "Versioned namespace {namespace} doesn't match stale config "
+                                  "namespace {staleNamespace}",
+                                  "Versioned namespace doesn't match stale config namespace",
+                                  "namespace"_attr = ns,
+                                  "staleNamespace"_attr = staleNS);
                 }
             }
         }
@@ -855,7 +986,10 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
 
         // Erase empty stuff
         if (!mdata.pcState) {
-            log() << "PCursor erasing empty state " << mdata.toBSON();
+            LOGV2(22689,
+                  "PCursor erasing empty connection state {connectionState}",
+                  "PCursor erasing empty connection state",
+                  "connectionState"_attr = mdata.toBSON());
             _cursorMap.erase(i++);
             continue;
         } else {
@@ -945,13 +1079,19 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
         bool firstPass = retryQueries.size() == 0;
 
         if (!firstPass) {
-            log() << "retrying " << (returnPartial ? "(partial) " : "")
-                  << "parallel connection to ";
-            for (set<int>::const_iterator it = retryQueries.begin(); it != retryQueries.end();
-                 ++it) {
-                log() << serverHosts[*it] << ", ";
-            }
-            log() << finishedQueries << " finished queries.";
+            vector<StringData> serverHostsToRetry;
+            serverHostsToRetry.reserve(retryQueries.size());
+            transform(retryQueries.begin(),
+                      retryQueries.end(),
+                      std::back_inserter(serverHostsToRetry),
+                      [&](const auto& query) { return serverHosts[query]; });
+            LOGV2(22690,
+                  "Finished queries {finishedQueriesCount}, retrying parallel connection to "
+                  "{serverHostsToRetry}",
+                  "Retrying parallel connection",
+                  "returnPartial"_attr = returnPartial,
+                  "finishedQueriesCount"_attr = finishedQueries,
+                  "serverHostsToRetry"_attr = serverHostsToRetry);
         }
 
         size_t num = 0;
@@ -996,34 +1136,39 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
                 break;
             }
 
-            LOG(5) << "ParallelSortClusteredCursor::init server:" << serverHost << " ns:" << _ns
-                   << " query:" << redact(_query) << " fields:" << redact(_fields)
-                   << " options: " << _options;
+            LOGV2_DEBUG(22693,
+                        5,
+                        "ParallelSortClusteredCursor initialization",
+                        "serverHost"_attr = serverHost,
+                        "namespace"_attr = _ns,
+                        "query"_attr = redact(_query),
+                        "fields"_attr = redact(_fields),
+                        "options"_attr = _options);
 
             if (!_cursors[i].get())
                 _cursors[i].reset(
                     new DBClientCursor(conns[i]->get(),
                                        NamespaceString(_ns),
                                        _query,
-                                       0,                                 // nToReturn
-                                       0,                                 // nToSkip
-                                       _fields.isEmpty() ? 0 : &_fields,  // fieldsToReturn
+                                       0,                                       // nToReturn
+                                       0,                                       // nToSkip
+                                       _fields.isEmpty() ? nullptr : &_fields,  // fieldsToReturn
                                        _options,
                                        _batchSize == 0 ? 0 : _batchSize + _needToSkip  // batchSize
                                        ),
-                    NULL);
+                    nullptr);
 
             try {
                 _cursors[i].get()->initLazy(!firstPass);
             } catch (NetworkException& e) {
                 socketExs.push_back(e.what() + errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 if (!returnPartial)
                     break;
             } catch (std::exception& e) {
                 otherExs.push_back(e.what() + errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 break;
             }
@@ -1049,9 +1194,12 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
 
             try {
                 if (!_cursors[i].get()->initLazyFinish(retry)) {
-                    warning() << "invalid result from " << conns[i]->getHost()
-                              << (retry ? ", retrying" : "");
-                    _cursors[i].reset(NULL, NULL);
+                    LOGV2_WARNING(22712,
+                                  "Got invalid result from {host}",
+                                  "Got invalid result",
+                                  "host"_attr = conns[i]->getHost(),
+                                  "retrying"_attr = retry);
+                    _cursors[i].reset(nullptr, nullptr);
 
                     if (!retry) {
                         socketExs.push_back(str::stream()
@@ -1071,17 +1219,17 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
                 staleConfigExs.push_back(
                     (string) "stale config detected when receiving response for " + e.toString() +
                     errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 continue;
             } catch (NetworkException& e) {
                 socketExs.push_back(e.what() + errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 continue;
             } catch (std::exception& e) {
                 otherExs.push_back(e.what() + errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 continue;
             }
@@ -1100,12 +1248,12 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
 
                 staleConfigExs.push_back((string) "stale config detected for " + e.toString() +
                                          errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 continue;
             } catch (std::exception& e) {
                 otherExs.push_back(e.what() + errLoc);
-                _cursors[i].reset(NULL, NULL);
+                _cursors[i].reset(nullptr, nullptr);
                 conns[i]->done();
                 continue;
             }
@@ -1148,17 +1296,24 @@ void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
             // Version is zero b/c this is deprecated codepath
             uasserted(StaleConfigInfo(NamespaceString(_ns),
                                       ChunkVersion(0, 0, OID()),
-                                      ChunkVersion(0, 0, OID())),
+                                      ChunkVersion(0, 0, OID()),
+                                      boost::none),
                       errMsg.str());
         } else if (throwException) {
             uasserted(14827, errMsg.str());
         } else {
-            warning() << redact(errMsg.str());
+            LOGV2_WARNING(22713,
+                          "Error while initializing cursor across all shards caused by {error}",
+                          "Error while initializing cursor across all shards",
+                          "error"_attr = redact(errMsg.str()));
         }
     }
 
     if (retries > 0)
-        log() << "successfully finished parallel query after " << retries << " retries";
+        LOGV2(22694,
+              "Successfully finished parallel query after {retries} retries",
+              "Successfully finished parallel query",
+              "retries"_attr = retries);
 }
 
 bool ParallelSortClusteredCursor::more() {
@@ -1251,9 +1406,9 @@ void ParallelConnectionMetadata::cleanup(bool full) {
                     bool retry = false;
                     pcState->cursor->initLazyFinish(retry);
                 } catch (std::exception&) {
-                    warning() << "exception closing cursor";
+                    LOGV2_WARNING(22714, "Exception closing cursor");
                 } catch (...) {
-                    warning() << "unknown exception closing cursor";
+                    LOGV2_WARNING(22715, "Unknown exception closing cursor");
                 }
             }
         }
