@@ -82,9 +82,12 @@ BSONObj getCollation(const BSONObj& cmdObj) {
     return BSONObj();
 }
 
-BSONObj getShardKey(OperationContext* opCtx, const ChunkManager& chunkMgr, const BSONObj& query) {
+BSONObj getShardKey(OperationContext* opCtx,
+                    const ChunkManager& chunkMgr,
+                    const NamespaceString& nss,
+                    const BSONObj& query) {
     BSONObj shardKey =
-        uassertStatusOK(chunkMgr.getShardKeyPattern().extractShardKeyFromQuery(opCtx, query));
+        uassertStatusOK(chunkMgr.getShardKeyPattern().extractShardKeyFromQuery(opCtx, nss, query));
     uassert(ErrorCodes::ShardKeyNotFound,
             "Query for sharded findAndModify must contain the shard key",
             !shardKey.isEmpty());
@@ -104,7 +107,7 @@ void updateShardKeyValueOnWouldChangeOwningShardError(OperationContext* opCtx,
 
     try {
         auto matchedDocOrUpserted = documentShardKeyUpdateUtil::updateShardKeyForDocument(
-            opCtx, nss, wouldChangeOwningShardExtraInfo, cmdObj.getIntField("stmtId"));
+            opCtx, nss, wouldChangeOwningShardExtraInfo);
         auto upserted = matchedDocOrUpserted && wouldChangeOwningShardExtraInfo.getShouldUpsert();
         auto updatedExistingDocument = matchedDocOrUpserted && !upserted;
 
@@ -155,10 +158,12 @@ public:
         return true;
     }
 
-    bool supportsReadConcern(const std::string& dbName,
-                             const BSONObj& cmdObj,
-                             repl::ReadConcernLevel level) const final {
-        return true;
+    ReadConcernSupportResult supportsReadConcern(const BSONObj& cmdObj,
+                                                 repl::ReadConcernLevel level) const final {
+        return {{level != repl::ReadConcernLevel::kLocalReadConcern &&
+                     level != repl::ReadConcernLevel::kSnapshotReadConcern,
+                 {ErrorCodes::InvalidOptions, "read concern not supported"}},
+                {{ErrorCodes::InvalidOptions, "default read concern not permitted"}}};
     }
 
     void addRequiredPrivileges(const std::string& dbname,
@@ -188,7 +193,7 @@ public:
 
             const BSONObj query = cmdObj.getObjectField("query");
             const BSONObj collation = getCollation(cmdObj);
-            const BSONObj shardKey = getShardKey(opCtx, *chunkMgr, query);
+            const BSONObj shardKey = getShardKey(opCtx, *chunkMgr, nss, query);
             const auto chunk = chunkMgr->findIntersectingChunk(shardKey, collation);
 
             shard = uassertStatusOK(
@@ -201,12 +206,27 @@ public:
         // Time how long it takes to run the explain command on the shard.
         Timer timer;
         BSONObjBuilder bob;
-        _runCommand(opCtx,
-                    shard->getId(),
-                    (chunkMgr ? chunkMgr->getVersion(shard->getId()) : ChunkVersion::UNSHARDED()),
-                    nss,
-                    explainCmd,
-                    &bob);
+
+        if (chunkMgr) {
+            _runCommand(opCtx,
+                        shard->getId(),
+                        chunkMgr->getVersion(shard->getId()),
+                        boost::none,
+                        nss,
+                        applyReadWriteConcern(opCtx, false, false, explainCmd),
+                        &bob);
+        } else {
+            _runCommand(
+                opCtx,
+                shard->getId(),
+                boost::make_optional(!databaseVersion::isFixed(routingInfo.db().databaseVersion()),
+                                     ChunkVersion::UNSHARDED()),
+                routingInfo.db().databaseVersion(),
+                nss,
+                applyReadWriteConcern(opCtx, false, false, explainCmd),
+                &bob);
+        }
+
         const auto millisElapsed = timer.millis();
 
         Strategy::CommandResult cmdResult;
@@ -240,12 +260,15 @@ public:
 
         const auto routingInfo = uassertStatusOK(getCollectionRoutingInfoForTxnCmd(opCtx, nss));
         if (!routingInfo.cm()) {
-            _runCommand(opCtx,
-                        routingInfo.db().primaryId(),
-                        ChunkVersion::UNSHARDED(),
-                        nss,
-                        cmdObjForShard,
-                        &result);
+            _runCommand(
+                opCtx,
+                routingInfo.db().primaryId(),
+                boost::make_optional(!databaseVersion::isFixed(routingInfo.db().databaseVersion()),
+                                     ChunkVersion::UNSHARDED()),
+                routingInfo.db().databaseVersion(),
+                nss,
+                applyReadWriteConcern(opCtx, this, cmdObjForShard),
+                &result);
             return true;
         }
 
@@ -253,7 +276,7 @@ public:
 
         const BSONObj query = cmdObjForShard.getObjectField("query");
         const BSONObj collation = getCollation(cmdObjForShard);
-        const BSONObj shardKey = getShardKey(opCtx, *chunkMgr, query);
+        const BSONObj shardKey = getShardKey(opCtx, *chunkMgr, nss, query);
 
         // For now, set bypassIsFieldHashedCheck to be true in order to skip the
         // isFieldHashedCheck in the special case where _id is hashed and used as the shard key.
@@ -264,8 +287,9 @@ public:
         _runCommand(opCtx,
                     chunk.getShardId(),
                     chunkMgr->getVersion(chunk.getShardId()),
+                    boost::none,
                     nss,
-                    cmdObjForShard,
+                    applyReadWriteConcern(opCtx, this, cmdObjForShard),
                     &result);
 
         return true;
@@ -274,17 +298,23 @@ public:
 private:
     static void _runCommand(OperationContext* opCtx,
                             const ShardId& shardId,
-                            const ChunkVersion& shardVersion,
+                            const boost::optional<ChunkVersion>& shardVersion,
+                            const boost::optional<DatabaseVersion>& dbVersion,
                             const NamespaceString& nss,
                             const BSONObj& cmdObj,
                             BSONObjBuilder* result) {
         bool isRetryableWrite = opCtx->getTxnNumber() && !TransactionRouter::get(opCtx);
         const auto response = [&] {
             std::vector<AsyncRequestsSender::Request> requests;
-            requests.emplace_back(
-                shardId,
-                appendShardVersion(CommandHelpers::filterCommandRequestForPassthrough(cmdObj),
-                                   shardVersion));
+            BSONObj filteredCmdObj = CommandHelpers::filterCommandRequestForPassthrough(cmdObj);
+            BSONObj cmdObjWithVersions(std::move(filteredCmdObj));
+            if (dbVersion) {
+                cmdObjWithVersions = appendDbVersionIfPresent(cmdObjWithVersions, *dbVersion);
+            }
+            if (shardVersion) {
+                cmdObjWithVersions = appendShardVersion(cmdObjWithVersions, *shardVersion);
+            }
+            requests.emplace_back(shardId, cmdObjWithVersions);
 
             MultiStatementTransactionRequestsSender ars(
                 opCtx,
@@ -304,7 +334,8 @@ private:
 
         const auto responseStatus = getStatusFromCommandResult(response.data);
         if (ErrorCodes::isNeedRetargettingError(responseStatus.code()) ||
-            ErrorCodes::isSnapshotError(responseStatus.code())) {
+            ErrorCodes::isSnapshotError(responseStatus.code()) ||
+            responseStatus.code() == ErrorCodes::StaleDbVersion) {
             // Command code traps this exception and re-runs
             uassertStatusOK(responseStatus.withContext("findAndModify"));
         }
@@ -325,10 +356,14 @@ private:
                     // cmdObj.  The transaction commit will still use the WC, because it uses the WC
                     // from the opCtx (which has been set previously in Strategy).
                     documentShardKeyUpdateUtil::startTransactionForShardKeyUpdate(opCtx);
-                    _runCommand(
-                        opCtx, shardId, shardVersion, nss, stripWriteConcern(cmdObj), result);
+                    _runCommand(opCtx,
+                                shardId,
+                                shardVersion,
+                                dbVersion,
+                                nss,
+                                stripWriteConcern(cmdObj),
+                                result);
                     uassertStatusOK(getStatusFromCommandResult(result->asTempObj()));
-
                     auto commitResponse =
                         documentShardKeyUpdateUtil::commitShardKeyUpdateTransaction(opCtx);
 
