@@ -27,7 +27,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kControl
+#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kControl
 
 #include "mongo/platform/basic.h"
 
@@ -35,6 +35,7 @@
 
 #include <iostream>
 #include <malloc.h>
+#include <pcrecpp.h>
 #include <sched.h>
 #include <stdio.h>
 #include <sys/mman.h>
@@ -57,8 +58,8 @@
 #include <pcrecpp.h>
 
 #include "mongo/base/parse_number.h"
+#include "mongo/logv2/log.h"
 #include "mongo/util/file.h"
-#include "mongo/util/log.h"
 #include "mongo/util/static_immortal.h"
 
 #define KLONG long
@@ -361,8 +362,8 @@ public:
         char fstr[1024] = {0};
 
         f = fopen(fname, "r");
-        if (f != NULL) {
-            if (fgets(fstr, 1023, f) != NULL)
+        if (f != nullptr) {
+            if (fgets(fstr, 1023, f) != nullptr)
                 fstr[strlen(fstr) < 1 ? 0 : strlen(fstr) - 1] = '\0';
             fclose(f);
         }
@@ -461,7 +462,7 @@ public:
                     if (std::string(key).compare("DISTRIB_RELEASE") == 0)
                         version = val;
                 }
-            } catch (const std::out_of_range& e) {
+            } catch (const std::out_of_range&) {
                 // attempted to get invalid substr
             }
             // return with lsb-release data if we found both the name and version
@@ -543,10 +544,10 @@ public:
             meminfo = meminfo.substr(lineOff);
 
             unsigned long long systemMem = 0;
-            if (mongo::parseNumberFromString(meminfo, &systemMem).isOK()) {
+            if (mongo::NumberParser{}(meminfo, &systemMem).isOK()) {
                 return systemMem * 1024;  // convert from kB to bytes
             } else
-                log() << "Unable to collect system memory information";
+                LOGV2(23338, "Unable to collect system memory information");
         }
         return 0;
     }
@@ -565,7 +566,7 @@ public:
              }) {
             unsigned long long groupMemBytes = 0;
             std::string groupLimit = readLineFromFile(file);
-            if (!groupLimit.empty() && parseNumberFromString(groupLimit, &groupMemBytes).isOK()) {
+            if (!groupLimit.empty() && NumberParser{}(groupLimit, &groupMemBytes).isOK()) {
                 return std::min(systemMemBytes, groupMemBytes);
             }
         }
@@ -667,7 +668,10 @@ void ProcessInfo::SystemInfo::collectSystemInfo() {
     LinuxSysHelper::getLinuxDistro(distroName, distroVersion);
 
     if (uname(&unameData) == -1) {
-        log() << "Unable to collect detailed system information: " << strerror(errno);
+        auto e = errno;
+        LOGV2(23339,
+              "Unable to collect detailed system information",
+              "error"_attr = errnoWithDescription(e));
     }
 
     osType = "Linux";
@@ -722,8 +726,10 @@ bool ProcessInfo::checkNumaEnabled() {
         hasMultipleNodes = boost::filesystem::exists("/sys/devices/system/node/node1");
         hasNumaMaps = boost::filesystem::exists("/proc/self/numa_maps");
     } catch (boost::filesystem::filesystem_error& e) {
-        log() << "WARNING: Cannot detect if NUMA interleaving is enabled. "
-              << "Failed to probe \"" << e.path1().string() << "\": " << e.code().message();
+        LOGV2(23340,
+              "WARNING: Cannot detect if NUMA interleaving is enabled. Failed to probe",
+              "path"_attr = e.path1().string(),
+              "reason"_attr = e.code().message());
         return false;
     }
 
@@ -749,7 +755,8 @@ bool ProcessInfo::blockCheckSupported() {
 bool ProcessInfo::blockInMemory(const void* start) {
     unsigned char x = 0;
     if (mincore(const_cast<void*>(alignToStartOfPage(start)), getPageSize(), &x)) {
-        log() << "mincore failed: " << errnoWithDescription();
+        auto e = errno;
+        LOGV2(23341, "mincore failed", "error"_attr = errnoWithDescription(e));
         return 1;
     }
     return x & 0x1;
@@ -760,7 +767,8 @@ bool ProcessInfo::pagesInMemory(const void* start, size_t numPages, std::vector<
     if (mincore(const_cast<void*>(alignToStartOfPage(start)),
                 numPages * getPageSize(),
                 reinterpret_cast<unsigned char*>(&out->front()))) {
-        log() << "mincore failed: " << errnoWithDescription();
+        auto e = errno;
+        LOGV2(23342, "mincore failed", "error"_attr = errnoWithDescription(e));
         return false;
     }
     for (size_t i = 0; i < numPages; ++i) {
